@@ -3,9 +3,10 @@
 This module defines a class for a rectangular bounding box.
 """
 
-from astropy.io.fits.util import _is_int
-from astropy.utils import deprecated
+import math
+
 import numpy as np
+from astropy.utils.decorators import deprecated_renamed_argument
 
 __all__ = ['BoundingBox']
 
@@ -25,42 +26,41 @@ class BoundingBox:
 
     Examples
     --------
+    When constructing a BoundingBox, it's better to use keyword
+    arguments for readability:
+
     >>> from photutils.aperture import BoundingBox
-
-    >>> # constructing a BoundingBox like this is cryptic:
-    >>> bbox = BoundingBox(1, 10, 2, 20)
-
-    >>> # it's better to use keyword arguments for readability:
     >>> bbox = BoundingBox(ixmin=1, ixmax=10, iymin=2, iymax=20)
-    >>> bbox  # nice repr, useful for interactive work
+    >>> bbox
     BoundingBox(ixmin=1, ixmax=10, iymin=2, iymax=20)
 
-    >>> # sometimes it's useful to check if two bounding boxes are the same
+    Sometimes it's useful to check if two bounding boxes are the same:
+
     >>> bbox == BoundingBox(ixmin=1, ixmax=10, iymin=2, iymax=20)
     True
     >>> bbox == BoundingBox(ixmin=7, ixmax=10, iymin=2, iymax=20)
     False
 
-    >>> # "center" and "shape" can be useful when working with numpy arrays
+    The "center" and "shape" attributes can be useful when working with
+    numpy arrays:
+
     >>> bbox.center  # numpy order: (y, x)
     (10.5, 5.0)
     >>> bbox.shape  # numpy order: (y, x)
     (18, 9)
 
-    >>> # "extent" is useful when plotting the BoundingBox with matplotlib
-    >>> bbox.extent  # matplotlib order: (x, y)
+    The "extent" is useful when plotting the BoundingBox with
+    matplotlib:
+
+    >>> bbox.extent  # matplotlib order: (xmin, xmax, ymin, ymax)
     (0.5, 9.5, 1.5, 19.5)
     """
 
     def __init__(self, ixmin, ixmax, iymin, iymax):
-        if not _is_int(ixmin):
-            raise TypeError('ixmin must be an integer')
-        if not _is_int(ixmax):
-            raise TypeError('ixmax must be an integer')
-        if not _is_int(iymin):
-            raise TypeError('iymin must be an integer')
-        if not _is_int(iymax):
-            raise TypeError('iymax must be an integer')
+        for value in (ixmin, ixmax, iymin, iymax):
+            if not isinstance(value, (int, np.integer)):
+                raise TypeError('ixmin, ixmax, iymin, and iymax must all be '
+                                'integers')
 
         if ixmin > ixmax:
             raise ValueError('ixmin must be <= ixmax')
@@ -113,10 +113,10 @@ class BoundingBox:
         >>> BoundingBox.from_float(xmin=1.4, xmax=10.4, ymin=1.6, ymax=10.6)
         BoundingBox(ixmin=1, ixmax=11, iymin=2, iymax=12)
         """
-        ixmin = int(np.floor(xmin + 0.5))
-        ixmax = int(np.ceil(xmax + 0.5))
-        iymin = int(np.floor(ymin + 0.5))
-        iymax = int(np.ceil(ymax + 0.5))
+        ixmin = math.floor(xmin + 0.5)
+        ixmax = math.ceil(xmax + 0.5)
+        iymin = math.floor(ymin + 0.5)
+        iymax = math.ceil(ymax + 0.5)
 
         return cls(ixmin, ixmax, iymin, iymax)
 
@@ -219,25 +219,6 @@ class BoundingBox:
         return (self.ixmin - 0.5, self.ixmax - 0.5,
                 self.iymin - 0.5, self.iymax - 0.5)
 
-    @deprecated('0.7', alternative='as_artist')
-    def as_patch(self, **kwargs):  # pragma: no cover
-        """
-        Return a `matplotlib.patches.Rectangle` that represents the
-        bounding box.
-
-        Parameters
-        ----------
-        **kwargs : dict
-            Any keyword arguments accepted by
-            `matplotlib.patches.Patch`.
-
-        Returns
-        -------
-        result : `matplotlib.patches.Rectangle`
-            A matplotlib rectangular patch.
-        """
-        return self.as_artist(**kwargs)
-
     def as_artist(self, **kwargs):
         """
         Return a `matplotlib.patches.Rectangle` that represents the
@@ -259,9 +240,10 @@ class BoundingBox:
         .. plot::
             :include-source:
 
-            import numpy as np
             import matplotlib.pyplot as plt
+            import numpy as np
             from photutils.aperture import BoundingBox
+
             bbox = BoundingBox(2, 7, 3, 8)
             fig = plt.figure()
             ax = fig.add_subplot(1, 1, 1)
@@ -281,20 +263,22 @@ class BoundingBox:
         Return a `~photutils.aperture.RectangularAperture` that
         represents the bounding box.
         """
-        from .rectangle import RectangularAperture  # prevent circular import
+        # prevent circular import
+        from photutils.aperture.rectangle import RectangularAperture
 
         xypos = self.center[::-1]  # xy order
         height, width = self.shape
-        return RectangularAperture(xypos, w=width, h=height, theta=0.)
+        return RectangularAperture(xypos, w=width, h=height, theta=0.0)
 
-    def plot(self, axes=None, origin=(0, 0), **kwargs):
+    @deprecated_renamed_argument('axes', 'ax', '1.6.0')
+    def plot(self, ax=None, origin=(0, 0), **kwargs):
         """
         Plot the `BoundingBox` on a matplotlib `~matplotlib.axes.Axes`
         instance.
 
         Parameters
         ----------
-        axes : `matplotlib.axes.Axes` or `None`, optional
+        ax : `matplotlib.axes.Axes` or `None`, optional
             The matplotlib axes on which to plot.  If `None`, then the
             current `~matplotlib.axes.Axes` instance is used.
 
@@ -313,7 +297,7 @@ class BoundingBox:
             legend.
         """
         aper = self.to_aperture()
-        return aper.plot(axes=axes, origin=origin, **kwargs)[0]
+        return aper.plot(ax=ax, origin=origin, **kwargs)[0]
 
     def union(self, other):
         """
