@@ -6,13 +6,14 @@ pixel and sky coordinates.
 
 import math
 
-import numpy as np
+from astropy.utils import lazyproperty
 
-from .attributes import (PixelPositions, PositiveScalar, SkyCoordPositions,
-                         ScalarAngleOrPixel)
-from .core import PixelAperture, SkyAperture
-from .mask import ApertureMask
-from ..geometry import circular_overlap_grid
+from photutils.aperture.attributes import (PixelPositions, PositiveScalar,
+                                           PositiveScalarAngle,
+                                           SkyCoordPositions)
+from photutils.aperture.core import PixelAperture, SkyAperture
+from photutils.aperture.mask import ApertureMask
+from photutils.geometry import circular_overlap_grid
 
 __all__ = ['CircularMaskMixin', 'CircularAperture', 'CircularAnnulus',
            'SkyCircularAperture', 'SkyCircularAnnulus']
@@ -59,7 +60,7 @@ class CircularMaskMixin:
         subpixels : int, optional
             For the ``'subpixel'`` method, resample pixels by this
             factor in each dimension. That is, each pixel is divided
-            into ``subpixels ** 2`` subpixels. This keyword is ignored
+            into ``subpixels**2`` subpixels. This keyword is ignored
             unless ``method='subpixel'``.
 
         Returns
@@ -80,8 +81,7 @@ class CircularMaskMixin:
             raise ValueError('Cannot determine the aperture radius.')
 
         masks = []
-        for bbox, edges in zip(np.atleast_1d(self.bbox),
-                               self._centered_edges):
+        for bbox, edges in zip(self._bbox, self._centered_edges):
             ny, nx = bbox.shape
             mask = circular_overlap_grid(edges[0], edges[1], edges[2],
                                          edges[3], nx, ny, radius, use_exact,
@@ -116,9 +116,6 @@ class CircularAperture(CircularMaskMixin, PixelAperture):
 
             * single ``(x, y)`` pair as a tuple, list, or `~numpy.ndarray`
             * tuple, list, or `~numpy.ndarray` of ``(x, y)`` pairs
-            * `~astropy.units.Quantity` instance of ``(x, y)`` pairs in
-              pixel units (this is Deprecated and will be removed in a
-              future version)
 
     r : float
         The radius of the circle in pixels.
@@ -131,14 +128,14 @@ class CircularAperture(CircularMaskMixin, PixelAperture):
     Examples
     --------
     >>> from photutils.aperture import CircularAperture
-    >>> aper = CircularAperture([10., 20.], 3.)
-    >>> aper = CircularAperture((10., 20.), 3.)
+    >>> aper = CircularAperture([10.0, 20.0], 3.0)
+    >>> aper = CircularAperture((10.0, 20.0), 3.0)
 
-    >>> pos1 = (10., 20.)  # (x, y)
-    >>> pos2 = (30., 40.)
-    >>> pos3 = (50., 60.)
-    >>> aper = CircularAperture([pos1, pos2, pos3], 3.)
-    >>> aper = CircularAperture((pos1, pos2, pos3), 3.)
+    >>> pos1 = (10.0, 20.0)  # (x, y)
+    >>> pos2 = (30.0, 40.0)
+    >>> pos3 = (50.0, 60.0)
+    >>> aper = CircularAperture([pos1, pos2, pos3], 3.0)
+    >>> aper = CircularAperture((pos1, pos2, pos3), 3.0)
     """
 
     _params = ('positions', 'r')
@@ -149,13 +146,13 @@ class CircularAperture(CircularMaskMixin, PixelAperture):
         self.positions = positions
         self.r = r
 
-    @property
+    @lazyproperty
     def _xy_extents(self):
         return self.r, self.r
 
-    @property
+    @lazyproperty
     def area(self):
-        return math.pi * self.r ** 2
+        return math.pi * self.r**2
 
     def _to_patch(self, origin=(0, 0), **kwargs):
         """
@@ -233,9 +230,6 @@ class CircularAnnulus(CircularMaskMixin, PixelAperture):
 
             * single ``(x, y)`` pair as a tuple, list, or `~numpy.ndarray`
             * tuple, list, or `~numpy.ndarray` of ``(x, y)`` pairs
-            * `~astropy.units.Quantity` instance of ``(x, y)`` pairs in
-              pixel units (this is Deprecated and will be removed in a
-              future version)
 
     r_in : float
         The inner radius of the circular annulus in pixels.
@@ -254,14 +248,14 @@ class CircularAnnulus(CircularMaskMixin, PixelAperture):
     Examples
     --------
     >>> from photutils.aperture import CircularAnnulus
-    >>> aper = CircularAnnulus([10., 20.], 3., 5.)
-    >>> aper = CircularAnnulus((10., 20.), 3., 5.)
+    >>> aper = CircularAnnulus([10.0, 20.0], 3.0, 5.0)
+    >>> aper = CircularAnnulus((10.0, 20.0), 3.0, 5.0)
 
-    >>> pos1 = (10., 20.)  # (x, y)
-    >>> pos2 = (30., 40.)
-    >>> pos3 = (50., 60.)
-    >>> aper = CircularAnnulus([pos1, pos2, pos3], 3., 5.)
-    >>> aper = CircularAnnulus((pos1, pos2, pos3), 3., 5.)
+    >>> pos1 = (10.0, 20.0)  # (x, y)
+    >>> pos2 = (30.0, 40.0)
+    >>> pos3 = (50.0, 60.0)
+    >>> aper = CircularAnnulus([pos1, pos2, pos3], 3.0, 5.0)
+    >>> aper = CircularAnnulus((pos1, pos2, pos3), 3.0, 5.0)
     """
 
     _params = ('positions', 'r_in', 'r_out')
@@ -277,13 +271,13 @@ class CircularAnnulus(CircularMaskMixin, PixelAperture):
         self.r_in = r_in
         self.r_out = r_out
 
-    @property
+    @lazyproperty
     def _xy_extents(self):
         return self.r_out, self.r_out
 
-    @property
+    @lazyproperty
     def area(self):
-        return math.pi * (self.r_out ** 2 - self.r_in ** 2)
+        return math.pi * (self.r_out**2 - self.r_in**2)
 
     def _to_patch(self, origin=(0, 0), **kwargs):
         """
@@ -362,21 +356,20 @@ class SkyCircularAperture(SkyAperture):
         either scalar coordinates or an array of coordinates.
 
     r : scalar `~astropy.units.Quantity`
-        The radius of the circle in angular units. Pixel units are now
-        deprecated.
+        The radius of the circle in angular units.
 
     Examples
     --------
     >>> from astropy.coordinates import SkyCoord
     >>> import astropy.units as u
     >>> from photutils.aperture import SkyCircularAperture
-    >>> positions = SkyCoord(ra=[10., 20.], dec=[30., 40.], unit='deg')
+    >>> positions = SkyCoord(ra=[10.0, 20.0], dec=[30.0, 40.0], unit='deg')
     >>> aper = SkyCircularAperture(positions, 0.5*u.arcsec)
     """
 
     _params = ('positions', 'r',)
     positions = SkyCoordPositions('The center position(s) in sky coordinates.')
-    r = ScalarAngleOrPixel('The radius in angular units.')
+    r = PositiveScalarAngle('The radius in angular units.')
 
     def __init__(self, positions, r):
         self.positions = positions
@@ -417,26 +410,24 @@ class SkyCircularAnnulus(SkyAperture):
         either scalar coordinates or an array of coordinates.
 
     r_in : scalar `~astropy.units.Quantity`
-        The inner radius of the circular annulus in angular units. Pixel
-        units are now deprecated.
+        The inner radius of the circular annulus in angular units.
 
     r_out : scalar `~astropy.units.Quantity`
-        The outer radius of the circular annulus in angular units. Pixel
-        units are now deprecated.
+        The outer radius of the circular annulus in angular units.
 
     Examples
     --------
     >>> from astropy.coordinates import SkyCoord
     >>> import astropy.units as u
     >>> from photutils.aperture import SkyCircularAnnulus
-    >>> positions = SkyCoord(ra=[10., 20.], dec=[30., 40.], unit='deg')
+    >>> positions = SkyCoord(ra=[10.0, 20.0], dec=[30.0, 40.0], unit='deg')
     >>> aper = SkyCircularAnnulus(positions, 0.5*u.arcsec, 1.0*u.arcsec)
     """
 
     _params = ('positions', 'r_in', 'r_out')
     positions = SkyCoordPositions('The center position(s) in sky coordinates.')
-    r_in = ScalarAngleOrPixel('The inner radius in angular units.')
-    r_out = ScalarAngleOrPixel('The outer radius in angular units.')
+    r_in = PositiveScalarAngle('The inner radius in angular units.')
+    r_out = PositiveScalarAngle('The outer radius in angular units.')
 
     def __init__(self, positions, r_in, r_out):
         if r_in.unit.physical_type != r_out.unit.physical_type:
