@@ -4,16 +4,20 @@ This module defines the base aperture classes.
 """
 
 import abc
+import inspect
 from copy import deepcopy
 
+import astropy.units as u
 import numpy as np
 from astropy.coordinates import SkyCoord
-import astropy.units as u
+from astropy.utils import lazyproperty
+from astropy.utils.decorators import deprecated_renamed_argument
 
-from .bounding_box import BoundingBox
-from ._photometry_utils import (_handle_units, _prepare_photometry_data,
-                                _validate_inputs)
-from ..utils._wcs_helpers import _pixel_scale_angle_at_skycoord
+from photutils.aperture._photometry_utils import (_handle_units,
+                                                  _prepare_photometry_data,
+                                                  _validate_inputs)
+from photutils.aperture.bounding_box import BoundingBox
+from photutils.utils._wcs_helpers import _pixel_scale_angle_at_skycoord
 
 __all__ = ['Aperture', 'SkyAperture', 'PixelAperture']
 
@@ -102,8 +106,8 @@ class Aperture(metaclass=abc.ABCMeta):
             return False
 
         # now check the parameter values
-        # Note that Quantity comparisons allow for different units
-        # if they directly convertible (e.g., 1. * u.deg == 60. * u.arcmin)
+        # Note that Quantity comparisons allow for different units if they
+        # are directly convertible (e.g., 1.0 * u.deg == 60.0 * u.arcmin)
         try:
             for param in self_params:
                 # np.any is used for SkyCoord array comparisons
@@ -123,6 +127,17 @@ class Aperture(metaclass=abc.ABCMeta):
         """
         return not (self == other)
 
+    @property
+    def _lazyproperties(self):
+        """
+        A list of all class lazyproperties (even in superclasses).
+        """
+        def islazyproperty(obj):
+            return isinstance(obj, lazyproperty)
+
+        return [i[0] for i in inspect.getmembers(self.__class__,
+                                                 predicate=islazyproperty)]
+
     def copy(self):
         """
         Make an independent (deep) copy.
@@ -132,7 +147,7 @@ class Aperture(metaclass=abc.ABCMeta):
             params_copy[param] = deepcopy(getattr(self, param))
         return self.__class__(**params_copy)
 
-    @property
+    @lazyproperty
     def shape(self):
         """
         The shape of the instance.
@@ -142,7 +157,7 @@ class Aperture(metaclass=abc.ABCMeta):
         else:
             return self.positions.shape[:-1]
 
-    @property
+    @lazyproperty
     def isscalar(self):
         """
         Whether the instance is scalar (i.e., a single position).
@@ -155,7 +170,7 @@ class PixelAperture(Aperture):
     Abstract base class for apertures defined in pixel coordinates.
     """
 
-    @property
+    @lazyproperty
     def _default_patch_properties(self):
         """
         A dictionary of default matplotlib.patches.Patch properties.
@@ -192,7 +207,7 @@ class PixelAperture(Aperture):
 
         return use_exact, subpixels
 
-    @property
+    @lazyproperty
     @abc.abstractmethod
     def _xy_extents(self):
         """
@@ -204,7 +219,29 @@ class PixelAperture(Aperture):
         """
         raise NotImplementedError('Needs to be implemented in a subclass.')
 
-    @property
+    @lazyproperty
+    def _positions(self):
+        """
+        The aperture positions, always as a 2D ndarray.
+        """
+        return np.atleast_2d(self.positions)
+
+    @lazyproperty
+    def _bbox(self):
+        """
+        The minimal bounding box for the aperture, always as a list of
+        `~photutils.aperture.BoundingBox` instances.
+        """
+        x_delta, y_delta = self._xy_extents
+        xmin = self._positions[:, 0] - x_delta
+        xmax = self._positions[:, 0] + x_delta
+        ymin = self._positions[:, 1] - y_delta
+        ymax = self._positions[:, 1] + y_delta
+
+        return [BoundingBox.from_float(x0, x1, y0, y1)
+                for x0, x1, y0, y1 in zip(xmin, xmax, ymin, ymax)]
+
+    @lazyproperty
     def bbox(self):
         """
         The minimal bounding box for the aperture.
@@ -213,22 +250,12 @@ class PixelAperture(Aperture):
         `~photutils.aperture.BoundingBox` is returned, otherwise a list
         of `~photutils.aperture.BoundingBox` is returned.
         """
-        positions = np.atleast_2d(self.positions)
-        x_delta, y_delta = self._xy_extents
-        xmin = positions[:, 0] - x_delta
-        xmax = positions[:, 0] + x_delta
-        ymin = positions[:, 1] - y_delta
-        ymax = positions[:, 1] + y_delta
-
-        bboxes = [BoundingBox.from_float(x0, x1, y0, y1)
-                  for x0, x1, y0, y1 in zip(xmin, xmax, ymin, ymax)]
-
         if self.isscalar:
-            return bboxes[0]
+            return self._bbox[0]
         else:
-            return bboxes
+            return self._bbox
 
-    @property
+    @lazyproperty
     def _centered_edges(self):
         """
         A list of ``(xmin, xmax, ymin, ymax)`` tuples, one for each
@@ -239,8 +266,7 @@ class PixelAperture(Aperture):
         functions.
         """
         edges = []
-        for position, bbox in zip(np.atleast_2d(self.positions),
-                                  np.atleast_1d(self.bbox)):
+        for position, bbox in zip(self._positions, self._bbox):
             xmin = bbox.ixmin - 0.5 - position[0]
             xmax = bbox.ixmax - 0.5 - position[0]
             ymin = bbox.iymin - 0.5 - position[1]
@@ -249,7 +275,7 @@ class PixelAperture(Aperture):
 
         return edges
 
-    @property
+    @lazyproperty
     def area(self):
         """
         The exact analytical area of the aperture shape.
@@ -297,7 +323,7 @@ class PixelAperture(Aperture):
         subpixels : int, optional
             For the ``'subpixel'`` method, resample pixels by this
             factor in each dimension. That is, each pixel is divided
-            into ``subpixels ** 2`` subpixels. This keyword is ignored
+            into ``subpixels**2`` subpixels. This keyword is ignored
             unless ``method='subpixel'``.
 
         Returns
@@ -312,9 +338,11 @@ class PixelAperture(Aperture):
 
     def area_overlap(self, data, *, mask=None, method='exact', subpixels=5):
         """
-        Return the areas of the aperture masks that overlap with the
-        data, i.e., how many pixels are actually used to calculate each
-        sum.
+        Return the pixel areas of the aperture masks that overlap with
+        the data.
+
+        In other words, this method returns the pixel area(s) within the
+        aperture(s) that are used to calculate the aperture sum(s).
 
         Parameters
         ----------
@@ -355,13 +383,14 @@ class PixelAperture(Aperture):
         subpixels : int, optional
             For the ``'subpixel'`` method, resample pixels by this
             factor in each dimension. That is, each pixel is divided
-            into ``subpixels ** 2`` subpixels. This keyword is ignored
+            into ``subpixels**2`` subpixels. This keyword is ignored
             unless ``method='subpixel'``.
 
         Returns
         -------
         areas : float or array_like
-            The overlapping areas between the aperture masks and the data.
+            The overlapping areas (in pixels**2) between the aperture
+            masks and the data.
         """
         apermasks = self.to_mask(method=method, subpixels=subpixels)
         if self.isscalar:
@@ -372,7 +401,7 @@ class PixelAperture(Aperture):
             if mask.shape != data.shape:
                 raise ValueError('mask and data must have the same shape')
 
-        data = np.ones_like(data)
+        data = np.ones(data.shape)  # pixels
         vals = [apermask.get_values(data, mask=mask) for apermask in apermasks]
         # if the aperture does not overlap the data return np.nan
         areas = [val.sum() if val.shape != (0,) else np.nan for val in vals]
@@ -465,7 +494,7 @@ class PixelAperture(Aperture):
         subpixels : int, optional
             For the ``'subpixel'`` method, resample pixels by this
             factor in each dimension. That is, each pixel is divided
-            into ``subpixels ** 2`` subpixels. This keyword is ignored
+            into ``subpixels**2`` subpixels. This keyword is ignored
             unless ``method='subpixel'``.
 
         Returns
@@ -552,7 +581,7 @@ class PixelAperture(Aperture):
             Any keyword arguments accepted by
             `matplotlib.patches.Patch`.
         """
-        xy_positions = deepcopy(np.atleast_2d(self.positions))
+        xy_positions = deepcopy(self._positions)
         xy_positions[:, 0] -= origin[0]
         xy_positions[:, 1] -= origin[1]
 
@@ -585,14 +614,15 @@ class PixelAperture(Aperture):
         """
         raise NotImplementedError('Needs to be implemented in a subclass.')
 
-    def plot(self, axes=None, origin=(0, 0), **kwargs):
+    @deprecated_renamed_argument('axes', 'ax', '1.6.0')
+    def plot(self, ax=None, origin=(0, 0), **kwargs):
         """
         Plot the aperture on a matplotlib `~matplotlib.axes.Axes`
         instance.
 
         Parameters
         ----------
-        axes : `matplotlib.axes.Axes` or `None`, optional
+        ax : `matplotlib.axes.Axes` or `None`, optional
             The matplotlib axes on which to plot.  If `None`, then the
             current `~matplotlib.axes.Axes` instance is used.
 
@@ -612,15 +642,15 @@ class PixelAperture(Aperture):
         """
         import matplotlib.pyplot as plt
 
-        if axes is None:
-            axes = plt.gca()
+        if ax is None:
+            ax = plt.gca()
 
         patches = self._to_patch(origin=origin, **kwargs)
         if self.isscalar:
             patches = (patches,)
 
         for patch in patches:
-            axes.add_patch(patch)
+            ax.add_patch(patch)
 
         return patches
 
