@@ -9,12 +9,13 @@ import math
 import astropy.units as u
 import numpy as np
 
-from .attributes import (ScalarAngle, PixelPositions, PositiveScalar,
-                         SkyCoordPositions, ScalarAngleOrPixel,
-                         ScalarAngleOrValue)
-from .core import PixelAperture, SkyAperture
-from .mask import ApertureMask
-from ..geometry import elliptical_overlap_grid
+from photutils.aperture.attributes import (PixelPositions, PositiveScalar,
+                                           PositiveScalarAngle, ScalarAngle,
+                                           ScalarAngleOrValue,
+                                           SkyCoordPositions)
+from photutils.aperture.core import PixelAperture, SkyAperture
+from photutils.aperture.mask import ApertureMask
+from photutils.geometry import elliptical_overlap_grid
 
 __all__ = ['EllipticalMaskMixin', 'EllipticalAperture', 'EllipticalAnnulus',
            'SkyEllipticalAperture', 'SkyEllipticalAnnulus']
@@ -61,7 +62,7 @@ class EllipticalMaskMixin:
         subpixels : int, optional
             For the ``'subpixel'`` method, resample pixels by this
             factor in each dimension. That is, each pixel is divided
-            into ``subpixels ** 2`` subpixels. This keyword is ignored
+            into ``subpixels**2`` subpixels. This keyword is ignored
             unless ``method='subpixel'``.
 
         Returns
@@ -84,8 +85,7 @@ class EllipticalMaskMixin:
             raise ValueError('Cannot determine the aperture shape.')
 
         masks = []
-        for bbox, edges in zip(np.atleast_1d(self.bbox),
-                               self._centered_edges):
+        for bbox, edges in zip(self._bbox, self._centered_edges):
             ny, nx = bbox.shape
             mask = elliptical_overlap_grid(edges[0], edges[1], edges[2],
                                            edges[3], nx, ny, a, b,
@@ -138,9 +138,6 @@ class EllipticalAperture(EllipticalMaskMixin, PixelAperture):
 
             * single ``(x, y)`` pair as a tuple, list, or `~numpy.ndarray`
             * tuple, list, or `~numpy.ndarray` of ``(x, y)`` pairs
-            * `~astropy.units.Quantity` instance of ``(x, y)`` pairs in
-              pixel units (this is Deprecated and will be removed in a
-              future version)
 
     a : float
         The semimajor axis of the ellipse in pixels.
@@ -165,14 +162,14 @@ class EllipticalAperture(EllipticalMaskMixin, PixelAperture):
     >>> from photutils.aperture import EllipticalAperture
 
     >>> theta = Angle(80, 'deg')
-    >>> aper = EllipticalAperture([10., 20.], 5., 3.)
-    >>> aper = EllipticalAperture((10., 20.), 5., 3., theta=theta)
+    >>> aper = EllipticalAperture([10.0, 20.0], 5.0, 3.0)
+    >>> aper = EllipticalAperture((10.0, 20.0), 5.0, 3.0, theta=theta)
 
-    >>> pos1 = (10., 20.)  # (x, y)
-    >>> pos2 = (30., 40.)
-    >>> pos3 = (50., 60.)
-    >>> aper = EllipticalAperture([pos1, pos2, pos3], 5., 3.)
-    >>> aper = EllipticalAperture((pos1, pos2, pos3), 5., 3., theta=theta)
+    >>> pos1 = (10.0, 20.0)  # (x, y)
+    >>> pos2 = (30.0, 40.0)
+    >>> pos3 = (50.0, 60.0)
+    >>> aper = EllipticalAperture([pos1, pos2, pos3], 5.0, 3.0)
+    >>> aper = EllipticalAperture((pos1, pos2, pos3), 5.0, 3.0, theta=theta)
     """
 
     _params = ('positions', 'a', 'b', 'theta')
@@ -183,7 +180,7 @@ class EllipticalAperture(EllipticalMaskMixin, PixelAperture):
                                'angular Quantity or value in radians from '
                                'the positive x axis.')
 
-    def __init__(self, positions, a, b, theta=0.):
+    def __init__(self, positions, a, b, theta=0.0):
         self.positions = positions
         self.a = a
         self.b = b
@@ -225,10 +222,10 @@ class EllipticalAperture(EllipticalMaskMixin, PixelAperture):
                                                                **kwargs)
 
         patches = []
-        theta_deg = self._theta_radians * 180. / np.pi
+        theta_deg = self._theta_radians * 180.0 / np.pi
         for xy_position in xy_positions:
-            patches.append(mpatches.Ellipse(xy_position, 2. * self.a,
-                                            2. * self.b, theta_deg,
+            patches.append(mpatches.Ellipse(xy_position, 2.0 * self.a,
+                                            2.0 * self.b, angle=theta_deg,
                                             **patch_kwargs))
 
         if self.isscalar:
@@ -276,9 +273,6 @@ class EllipticalAnnulus(EllipticalMaskMixin, PixelAperture):
 
             * single ``(x, y)`` pair as a tuple, list, or `~numpy.ndarray`
             * tuple, list, or `~numpy.ndarray` of ``(x, y)`` pairs
-            * `~astropy.units.Quantity` instance of ``(x, y)`` pairs in
-              pixel units (this is Deprecated and will be removed in a
-              future version)
 
     a_in : float
         The inner semimajor axis of the elliptical annulus in pixels.
@@ -318,14 +312,15 @@ class EllipticalAnnulus(EllipticalMaskMixin, PixelAperture):
     >>> from photutils.aperture import EllipticalAnnulus
 
     >>> theta = Angle(80, 'deg')
-    >>> aper = EllipticalAnnulus([10., 20.], 3., 8., 5.)
-    >>> aper = EllipticalAnnulus((10., 20.), 3., 8., 5., theta=theta)
+    >>> aper = EllipticalAnnulus([10.0, 20.0], 3.0, 8.0, 5.0)
+    >>> aper = EllipticalAnnulus((10.0, 20.0), 3.0, 8.0, 5.0, theta=theta)
 
-    >>> pos1 = (10., 20.)  # (x, y)
-    >>> pos2 = (30., 40.)
-    >>> pos3 = (50., 60.)
-    >>> aper = EllipticalAnnulus([pos1, pos2, pos3], 3., 8., 5.)
-    >>> aper = EllipticalAnnulus((pos1, pos2, pos3), 3., 8., 5., theta=theta)
+    >>> pos1 = (10.0, 20.0)  # (x, y)
+    >>> pos2 = (30.0, 40.0)
+    >>> pos3 = (50.0, 60.0)
+    >>> aper = EllipticalAnnulus([pos1, pos2, pos3], 3.0, 8.0, 5.0)
+    >>> aper = EllipticalAnnulus((pos1, pos2, pos3), 3.0, 8.0, 5.0,
+    ...                          theta=theta)
     """
 
     _params = ('positions', 'a_in', 'a_out', 'b_in', 'b_out', 'theta')
@@ -338,7 +333,7 @@ class EllipticalAnnulus(EllipticalMaskMixin, PixelAperture):
                                'angular Quantity or value in radians from '
                                'the positive x axis.')
 
-    def __init__(self, positions, a_in, a_out, b_out, b_in=None, theta=0.):
+    def __init__(self, positions, a_in, a_out, b_out, b_in=None, theta=0.0):
         if not a_out > a_in:
             raise ValueError('"a_out" must be greater than "a_in".')
 
@@ -392,12 +387,12 @@ class EllipticalAnnulus(EllipticalMaskMixin, PixelAperture):
                                                                **kwargs)
 
         patches = []
-        theta_deg = self._theta_radians * 180. / np.pi
+        theta_deg = self._theta_radians * 180.0 / np.pi
         for xy_position in xy_positions:
-            patch_inner = mpatches.Ellipse(xy_position, 2. * self.a_in,
-                                           2. * self.b_in, theta_deg)
-            patch_outer = mpatches.Ellipse(xy_position, 2. * self.a_out,
-                                           2. * self.b_out, theta_deg)
+            patch_inner = mpatches.Ellipse(xy_position, 2.0 * self.a_in,
+                                           2.0 * self.b_in, angle=theta_deg)
+            patch_outer = mpatches.Ellipse(xy_position, 2.0 * self.a_out,
+                                           2.0 * self.b_out, angle=theta_deg)
             path = self._make_annulus_path(patch_inner, patch_outer)
             patches.append(mpatches.PathPatch(path, **patch_kwargs))
 
@@ -445,12 +440,10 @@ class SkyEllipticalAperture(SkyAperture):
         either scalar coordinates or an array of coordinates.
 
     a : scalar `~astropy.units.Quantity`
-        The semimajor axis of the ellipse in angular units. Pixel units
-        are now deprecated.
+        The semimajor axis of the ellipse in angular units.
 
     b : scalar `~astropy.units.Quantity`
-        The semiminor axis of the ellipse in angular units. Pixel units
-        are now deprecated.
+        The semiminor axis of the ellipse in angular units.
 
     theta : scalar `~astropy.units.Quantity`, optional
         The position angle (in angular units) of the ellipse semimajor
@@ -462,22 +455,18 @@ class SkyEllipticalAperture(SkyAperture):
     >>> from astropy.coordinates import SkyCoord
     >>> import astropy.units as u
     >>> from photutils.aperture import SkyEllipticalAperture
-    >>> positions = SkyCoord(ra=[10., 20.], dec=[30., 40.], unit='deg')
+    >>> positions = SkyCoord(ra=[10.0, 20.0], dec=[30.0, 40.0], unit='deg')
     >>> aper = SkyEllipticalAperture(positions, 1.0*u.arcsec, 0.5*u.arcsec)
     """
 
     _params = ('positions', 'a', 'b', 'theta')
     positions = SkyCoordPositions('The center position(s) in sky coordinates.')
-    a = ScalarAngleOrPixel('The semimajor axis in angular units.')
-    b = ScalarAngleOrPixel('The semiminor axis in angular units.')
+    a = PositiveScalarAngle('The semimajor axis in angular units.')
+    b = PositiveScalarAngle('The semiminor axis in angular units.')
     theta = ScalarAngle('The position angle in angular units of the ellipse '
                         'semimajor axis.')
 
-    def __init__(self, positions, a, b, theta=0. * u.deg):
-        if a.unit.physical_type != b.unit.physical_type:
-            raise ValueError('a and b should either both be angles '
-                             'or in pixels')
-
+    def __init__(self, positions, a, b, theta=0.0 * u.deg):
         self.positions = positions
         self.a = a
         self.b = b
@@ -518,21 +507,17 @@ class SkyEllipticalAnnulus(SkyAperture):
         either scalar coordinates or an array of coordinates.
 
     a_in : scalar `~astropy.units.Quantity`
-        The inner semimajor axis in angular units. Pixel units are now
-        deprecated.
+        The inner semimajor axis in angular units.
 
     a_out : scalar `~astropy.units.Quantity`
-        The outer semimajor axis in angular units. Pixel units are now
-        deprecated.
+        The outer semimajor axis in angular units.
 
     b_out : scalar `~astropy.units.Quantity`
-        The outer semiminor axis in angular units. Pixel units are now
-        deprecated.
+        The outer semiminor axis in angular units.
 
     b_in : `None` or scalar `~astropy.units.Quantity`
-        The inner semiminor axis in angular units. Pixel units are
-        now deprecated. If `None`, then the inner semiminor axis is
-        calculated as:
+        The inner semiminor axis in angular units. If `None`, then the
+        inner semiminor axis is calculated as:
 
             .. math:: b_{in} = b_{out}
                 \left(\frac{a_{in}}{a_{out}}\right)
@@ -547,28 +532,22 @@ class SkyEllipticalAnnulus(SkyAperture):
     >>> from astropy.coordinates import SkyCoord
     >>> import astropy.units as u
     >>> from photutils.aperture import SkyEllipticalAnnulus
-    >>> positions = SkyCoord(ra=[10., 20.], dec=[30., 40.], unit='deg')
+    >>> positions = SkyCoord(ra=[10.0, 20.0], dec=[30.0, 40.0], unit='deg')
     >>> aper = SkyEllipticalAnnulus(positions, 0.5*u.arcsec, 2.0*u.arcsec,
     ...                             1.0*u.arcsec)
     """
 
     _params = ('positions', 'a_in', 'a_out', 'b_in', 'b_out', 'theta')
     positions = SkyCoordPositions('The center position(s) in sky coordinates.')
-    a_in = ScalarAngleOrPixel('The inner semimajor axis in angular units.')
-    a_out = ScalarAngleOrPixel('The outer semimajor axis in angular units.')
-    b_in = ScalarAngleOrPixel('The inner semiminor axis in angular units.')
-    b_out = ScalarAngleOrPixel('The outer semiminor axis in angular units.')
+    a_in = PositiveScalarAngle('The inner semimajor axis in angular units.')
+    a_out = PositiveScalarAngle('The outer semimajor axis in angular units.')
+    b_in = PositiveScalarAngle('The inner semiminor axis in angular units.')
+    b_out = PositiveScalarAngle('The outer semiminor axis in angular units.')
     theta = ScalarAngle('The position angle in angular units of the ellipse '
                         'semimajor axis.')
 
     def __init__(self, positions, a_in, a_out, b_out, b_in=None,
-                 theta=0. * u.deg):
-        if a_in.unit.physical_type != a_out.unit.physical_type:
-            raise ValueError('a_in and a_out should either both be angles '
-                             'or in pixels')
-        if a_out.unit.physical_type != b_out.unit.physical_type:
-            raise ValueError('a_out and b_out should either both be angles '
-                             'or in pixels')
+                 theta=0.0 * u.deg):
         if not a_out > a_in:
             raise ValueError('"a_out" must be greater than "a_in".')
 
@@ -580,9 +559,6 @@ class SkyEllipticalAnnulus(SkyAperture):
         if b_in is None:
             b_in = self.b_out * self.a_in / self.a_out
         else:
-            if b_in.unit.physical_type != b_out.unit.physical_type:
-                raise ValueError('b_in and b_out should either both be '
-                                 'angles or in pixels')
             if not b_out > b_in:
                 raise ValueError('"b_out" must be greater than "b_in".')
         self.b_in = b_in
