@@ -2,6 +2,7 @@
 """
 This module defines a class for aperture masks.
 """
+
 import warnings
 
 import astropy.units as u
@@ -35,12 +36,12 @@ class ApertureMask:
         self.bbox = bbox
         self._mask = (self.data == 0)
 
-    def __array__(self):
+    def __array__(self, dtype=None):
         """
         Array representation of the mask data array (e.g., for
         matplotlib).
         """
-        return self.data
+        return np.asarray(self.data, dtype=dtype)
 
     @property
     def shape(self):
@@ -77,7 +78,7 @@ class ApertureMask:
         """
         return self.bbox.get_overlap_slices(shape)
 
-    def to_image(self, shape):
+    def to_image(self, shape, dtype=float):
         """
         Return an image of the mask in a 2D array of the given shape,
         taking any edge effects into account.
@@ -87,6 +88,14 @@ class ApertureMask:
         shape : tuple of int
             The ``(ny, nx)`` shape of the output array.
 
+        dtype : data-type, optional
+            The desired data type for the array. This should be a
+            floating data type if the `ApertureMask` was created with
+            the "exact" or "subpixel" mode, otherwise the fractional
+            mask weights will be altered. A integer data type may be
+            used if the `ApertureMask` was created with the "center"
+            mode.
+
         Returns
         -------
         result : `~numpy.ndarray`
@@ -102,11 +111,11 @@ class ApertureMask:
             return None  # no overlap
 
         # insert the mask into the output image
-        image = np.zeros(shape)
+        image = np.zeros(shape, dtype=dtype)
         image[slices_large] = self.data[slices_small]
         return image
 
-    def cutout(self, data, fill_value=0., copy=False):
+    def cutout(self, data, fill_value=0.0, copy=False):
         """
         Create a cutout from the input data over the mask bounding box,
         taking any edge effects into account.
@@ -173,7 +182,7 @@ class ApertureMask:
 
         return cutout
 
-    def multiply(self, data, fill_value=0.):
+    def multiply(self, data, fill_value=0.0):
         """
         Multiply the aperture mask with the input data, taking any edge
         effects into account.
