@@ -4,22 +4,24 @@ This module provides tools for calculating the properties of sources
 defined by an Aperture.
 """
 
-from copy import deepcopy
 import functools
 import inspect
 import warnings
+from copy import deepcopy
 
-from astropy.stats import (SigmaClip, mad_std, biweight_location,
-                           biweight_midvariance)
-from astropy.table import QTable
 import astropy.units as u
-from astropy.utils import lazyproperty
 import numpy as np
+from astropy.nddata import NDData, StdDevUncertainty
+from astropy.stats import (SigmaClip, biweight_location, biweight_midvariance,
+                           mad_std)
+from astropy.table import QTable
+from astropy.utils import lazyproperty
+from astropy.utils.exceptions import AstropyUserWarning
 
-from . import Aperture, SkyAperture
-from ..utils._misc import _get_meta
-from ..utils._moments import _moments, _moments_central
-from ..utils._quantity_helpers import process_quantities
+from photutils.aperture import Aperture, SkyAperture
+from photutils.utils._misc import _get_meta
+from photutils.utils._moments import _moments, _moments_central
+from photutils.utils._quantity_helpers import process_quantities
 
 __all__ = ['ApertureStats']
 
@@ -37,6 +39,7 @@ def as_scalar(method):
     """
     Return a scalar value from a method if the class is scalar.
     """
+
     @functools.wraps(method)
     def _decorator(*args, **kwargs):
         result = method(*args, **kwargs)
@@ -45,6 +48,7 @@ def as_scalar(method):
                     else result)
         except TypeError:  # if result has no len
             return result
+
     return _decorator
 
 
@@ -53,9 +57,15 @@ class ApertureStats:
     Class to create a catalog of statistics for pixels within an
     aperture.
 
+    Note that this class returns the statistics of the input
+    ``data`` values within the aperture. It does not convert data
+    in surface brightness units to flux or counts. Conversion from
+    surface-brightness units should be performed before using this
+    function.
+
     Parameters
     ----------
-    data : 2D `~numpy.ndarray` or `~astropy.units.Quantity`, optional
+    data : 2D `~numpy.ndarray`, `~astropy.units.Quantity`, `~astropy.nddata.NDData`
         The 2D array from which to calculate the source properties.
         For accurate source properties, ``data`` should be
         background-subtracted. Non-finite ``data`` values (NaN and inf)
@@ -130,7 +140,7 @@ class ApertureStats:
     subpixels : int, optional
         For the ``'subpixel'`` method, resample pixels by this factor
         in each dimension. That is, each pixel is divided into
-        ``subpixels ** 2`` subpixels. This keyword is ignored unless
+        ``subpixels**2`` subpixels. This keyword is ignored unless
         ``sum_method='subpixel'``.
 
     local_bkg : float, `~numpy.ndarray`,  `~astropy.units.Quantity`, or `None`
@@ -200,6 +210,9 @@ class ApertureStats:
                  sigma_clip=None, sum_method='exact', subpixels=5,
                  local_bkg=None):
 
+        if isinstance(data, NDData):
+            data, error, mask, wcs = self.unpack_nddata(data, error, mask, wcs)
+
         (data, error, local_bkg), unit = process_quantities(
             (data, error, local_bkg), ('data', 'error', 'local_bkg'))
         self._data = self._validate_array(data, 'data', shape=False)
@@ -239,6 +252,31 @@ class ApertureStats:
         self.default_columns = DEFAULT_COLUMNS
         self.meta = _get_meta()
 
+    @staticmethod
+    def unpack_nddata(data, error, mask, wcs):
+        nddata_attr = {'error': error, 'mask': mask, 'wcs': wcs}
+        for key, value in nddata_attr.items():
+            if value is not None:
+                warnings.warn(f'The {key!r} keyword is be ignored. Its '
+                              'value is obtained from the input NDData '
+                              'object.', AstropyUserWarning)
+
+        mask = data.mask
+        wcs = data.wcs
+
+        if isinstance(data.uncertainty, StdDevUncertainty):
+            if data.uncertainty.unit is None:
+                error = data.uncertainty.array
+            else:
+                error = data.uncertainty.array * data.uncertainty.unit
+
+        if data.unit is not None:
+            data = u.Quantity(data.data, unit=data.unit)
+        else:
+            data = data.data
+
+        return data, error, mask, wcs
+
     @staticmethod
     def _validate_aperture(aperture):
         if not isinstance(aperture, Aperture):
@@ -261,6 +299,7 @@ class ApertureStats:
         """
         A list of all class lazyproperties (even in superclasses).
         """
+
         def islazyproperty(obj):
             return isinstance(obj, lazyproperty)
 
@@ -436,8 +475,10 @@ class ApertureStats:
         for id_num in np.atleast_1d(id_nums):
             if id_num not in self.ids:
                 raise ValueError(f'{id_num} is not a valid source ID number')
-        idx = np.searchsorted(self.id, id_nums)
-        return self[idx]
+
+        sorter = np.argsort(self.id)
+        indices = sorter[np.searchsorted(self.id, id_nums, sorter=sorter)]
+        return self[indices]
 
     def to_table(self, columns=None):
         """
@@ -611,7 +652,7 @@ class ApertureStats:
                     weight_cutout *= ~sigclip_mask
 
                     mask_cutout = data_sigclip.mask
-                    data_cutout = data_sigclip.filled(0.)
+                    data_cutout = data_sigclip.filled(0.0)
 
                 # need to apply the aperture weights
                 data_cutout *= aperweight_cutout
@@ -621,7 +662,7 @@ class ApertureStats:
                 else:
                     # apply the exact weights and total mask;
                     # error_cutout will have zeros where mask_cutout is True
-                    variance = self._error[slc_large] ** 2
+                    variance = self._error[slc_large]**2
                     variance_cutout = (variance * aperweight_cutout
                                        * ~mask_cutout)
 
@@ -839,7 +880,7 @@ class ApertureStats:
                 arr_.fill(np.nan)
             else:
                 arr_ = arr.data
-                arr_[arr.mask] = 0.
+                arr_[arr.mask] = 0.0
             cutouts.append(arr_)
 
         return cutouts
@@ -912,6 +953,9 @@ class ApertureStats:
         """
         The ``(x, y)`` coordinate, relative to the cutout data, of
         the centroid within the aperture.
+
+        The centroid is computed as the center of mass of the unmasked
+        pixels within the aperture.
         """
         moments = self.moments
         if self.isscalar:
@@ -928,8 +972,10 @@ class ApertureStats:
     @as_scalar
     def centroid(self):
         """
-        The ``(x, y)`` coordinate of the centroid of the unmasked pixels
-        within the aperture.
+        The ``(x, y)`` coordinate of the centroid.
+
+        The centroid is computed as the center of mass of the unmasked
+        pixels within the aperture.
         """
         origin = np.transpose((self.bbox_xmin, self.bbox_ymin))
         return self.cutout_centroid + origin
@@ -937,8 +983,7 @@ class ApertureStats:
     @lazyproperty
     def _xcentroid(self):
         """
-        The ``x`` coordinate of the centroid of the unmasked pixels
-        within the aperture, always as an iterable.
+        The ``x`` coordinate of the centroid, always as an iterable.
         """
         xcentroid = np.transpose(self.centroid)[0]
         if self.isscalar:
@@ -949,16 +994,17 @@ class ApertureStats:
     @as_scalar
     def xcentroid(self):
         """
-        The ``x`` coordinate of the centroid of the unmasked pixels
-        within the aperture.
+        The ``x`` coordinate of the centroid.
+
+        The centroid is computed as the center of mass of the unmasked
+        pixels within the aperture.
         """
         return self._xcentroid
 
     @lazyproperty
     def _ycentroid(self):
         """
-        The ``y`` coordinate of the centroid of the unmasked pixels
-        within the aperture, always as an iterable.
+        The ``y`` coordinate of the centroid, always as an iterable.
         """
         ycentroid = np.transpose(self.centroid)[1]
         if self.isscalar:
@@ -969,8 +1015,10 @@ class ApertureStats:
     @as_scalar
     def ycentroid(self):
         """
-        The ``y`` coordinate of the centroid of the unmasked pixels
-        within the aperture.
+        The ``y`` coordinate of the centroid.
+
+        The centroid is computed as the center of mass of the unmasked
+        pixels within the aperture.
         """
         return self._ycentroid
 
@@ -1109,10 +1157,10 @@ class ApertureStats:
         The total area of the unmasked pixels within the aperture using
         the "center" aperture mask method.
         """
-        areas = np.array([np.sum(weight.filled(0.))
+        areas = np.array([np.sum(weight.filled(0.0))
                           for weight in self._weight_cutout_center])
         areas[self._all_masked] = np.nan
-        return areas << (u.pix ** 2)
+        return areas << (u.pix**2)
 
     @lazyproperty
     @as_scalar
@@ -1121,10 +1169,10 @@ class ApertureStats:
         The total area of the unmasked pixels within the aperture using
         the input ``sum_method`` aperture mask method.
         """
-        areas = np.array([np.sum(weight.filled(0.))
+        areas = np.array([np.sum(weight.filled(0.0))
                           for weight in self._weight_cutout])
         areas[self._all_masked] = np.nan
-        return areas << (u.pix ** 2)
+        return areas << (u.pix**2)
 
     @lazyproperty
     @as_scalar
@@ -1179,7 +1227,10 @@ class ApertureStats:
                 variance = self._variance_cutout_center
             else:
                 variance = self._variance_cutout
-            err = np.sqrt([np.sum(arr) for arr in variance])
+
+            var_values = [arr.compressed() if len(arr.compressed()) > 0
+                          else np.array([np.nan]) for arr in variance]
+            err = np.sqrt([np.sum(arr) for arr in var_values])
 
         if self._data_unit is not None:
             err <<= self._data_unit
@@ -1225,7 +1276,7 @@ class ApertureStats:
 
         The mode is estimated as ``(3 * median) - (2 * mean)``.
         """
-        return 3. * self.median - 2. * self.mean
+        return 3.0 * self.median - 2.0 * self.mean
 
     @lazyproperty
     @as_scalar
@@ -1329,7 +1380,7 @@ class ApertureStats:
         # Modify the covariance matrix in the case of "infinitely" thin
         # detections. This follows SourceExtractor's prescription of
         # incrementally increasing the diagonal elements by 1/12.
-        delta = 1. / 12
+        delta = 1.0 / 12
         delta2 = delta**2
         # ignore RuntimeWarning from NaN values in covar
         with warnings.catch_warnings():
@@ -1436,9 +1487,9 @@ class ApertureStats:
         The angle increases in the counter-clockwise direction.
         """
         covar = self._covariance
-        orient_radians = 0.5 * np.arctan2(2. * covar[:, 0, 1],
+        orient_radians = 0.5 * np.arctan2(2.0 * covar[:, 0, 1],
                                           (covar[:, 0, 0] - covar[:, 1, 1]))
-        return orient_radians * 180. / np.pi * u.deg
+        return orient_radians * 180.0 / np.pi * u.deg
 
     @lazyproperty
     @as_scalar
@@ -1456,7 +1507,7 @@ class ApertureStats:
         and semiminor axes, respectively.
         """
         semimajor_var, semiminor_var = np.transpose(self.covariance_eigvals)
-        return np.sqrt(1. - (semiminor_var / semimajor_var))
+        return np.sqrt(1.0 - (semiminor_var / semimajor_var))
 
     @lazyproperty
     @as_scalar
@@ -1573,9 +1624,9 @@ class ApertureStats:
         isophotal limit of a source is well represented by :math:`R
         \approx 3`.
         """
-        return (2. * np.cos(self.orientation) * np.sin(self.orientation)
-                * ((1. / self.semimajor_sigma**2)
-                   - (1. / self.semiminor_sigma**2)))
+        return (2.0 * np.cos(self.orientation) * np.sin(self.orientation)
+                * ((1.0 / self.semimajor_sigma**2)
+                   - (1.0 / self.semiminor_sigma**2)))
 
     @lazyproperty
     @as_scalar
@@ -1612,7 +1663,7 @@ class ApertureStats:
                 continue
             npix = np.size(arr)
             normalization = np.abs(np.mean(arr)) * npix * (npix - 1)
-            kernel = ((2. * np.arange(1, npix + 1) - npix - 1)
+            kernel = ((2.0 * np.arange(1, npix + 1) - npix - 1)
                       * np.abs(np.sort(arr)))
             gini.append(np.sum(kernel) / normalization)
         return np.array(gini)
