@@ -6,19 +6,21 @@ RMS in an image.
 
 import warnings
 
+import astropy.units as u
+import numpy as np
 from astropy.nddata import NDData
 from astropy.stats import SigmaClip
-import astropy.units as u
 from astropy.utils import lazyproperty
+from astropy.utils.decorators import deprecated_renamed_argument
 from astropy.utils.exceptions import AstropyUserWarning
-import numpy as np
 from numpy.lib.index_tricks import index_exp
 
-from .core import SExtractorBackground, StdBackgroundRMS
-from .interpolators import BkgZoomInterpolator
-from ..utils import ShepardIDWInterpolator
-from ..utils._parameters import as_pair
-from ..utils._stats import nanmedian
+from photutils.aperture import RectangularAperture
+from photutils.background.core import SExtractorBackground, StdBackgroundRMS
+from photutils.background.interpolators import BkgZoomInterpolator
+from photutils.utils import ShepardIDWInterpolator
+from photutils.utils._parameters import as_pair
+from photutils.utils._stats import nanmedian
 
 __all__ = ['Background2D']
 
@@ -330,7 +332,7 @@ class Background2D:
         #       be included
         #     - for exclude_percentile=100, all boxes will be included
         #       *unless* they are completely masked
-        threshold = self.exclude_percentile / 100. * self.box_npixels
+        threshold = self.exclude_percentile / 100.0 * self.box_npixels
 
         # always exclude completely masked boxes
         if self.exclude_percentile == 100:
@@ -591,7 +593,7 @@ class Background2D:
 
     @lazyproperty
     def _mesh_yxpos(self):
-        box_cen = (self.box_size - 1) / 2.
+        box_cen = (self.box_size - 1) / 2.0
         return (self._mesh_idx * self.box_size[:, None]) + box_cen[:, None]
 
     @lazyproperty
@@ -653,7 +655,8 @@ class Background2D:
             bkg_rms <<= self.unit
         return bkg_rms
 
-    def plot_meshes(self, *, axes=None, marker='+', markersize=None,
+    @deprecated_renamed_argument('axes', 'ax', '1.6.0')
+    def plot_meshes(self, *, ax=None, marker='+', markersize=None,
                     color='blue', alpha=None, outlines=False, **kwargs):
         """
         Plot the low-resolution mesh boxes on a matplotlib Axes
@@ -661,7 +664,7 @@ class Background2D:
 
         Parameters
         ----------
-        axes : `matplotlib.axes.Axes` or `None`, optional
+        ax : `matplotlib.axes.Axes` or `None`, optional
             The matplotlib axes on which to plot.  If `None`, then the
             current `~matplotlib.axes.Axes` instance is used.
 
@@ -695,15 +698,14 @@ class Background2D:
         import matplotlib.pyplot as plt
 
         kwargs['color'] = color
-        if axes is None:
-            axes = plt.gca()
+        if ax is None:
+            ax = plt.gca()
 
-        axes.scatter(*self._mesh_xypos, s=markersize, marker=marker,
-                     color=color, alpha=alpha)
+        ax.scatter(*self._mesh_xypos, s=markersize, marker=marker,
+                   color=color, alpha=alpha)
 
         if outlines:
-            from ..aperture import RectangularAperture
             xypos = np.column_stack(self._mesh_xypos)
             apers = RectangularAperture(xypos, self.box_size[1],
-                                        self.box_size[0], 0.)
-            apers.plot(axes=axes, alpha=alpha, **kwargs)
+                                        self.box_size[0], 0.0)
+            apers.plot(ax=ax, alpha=alpha, **kwargs)
