@@ -6,19 +6,17 @@ The module contains tools for centroiding sources.
 import inspect
 import warnings
 
-from astropy.nddata.utils import overlap_slices
-from astropy.utils.decorators import deprecated_renamed_argument
-from astropy.utils.exceptions import AstropyUserWarning
 import numpy as np
+from astropy.nddata.utils import overlap_slices
+from astropy.utils.exceptions import AstropyUserWarning
 
-from ..utils._round import _py2intround
-from ..utils._parameters import as_pair
+from photutils.utils._parameters import as_pair
+from photutils.utils._round import _py2intround
 
 __all__ = ['centroid_com', 'centroid_quadratic', 'centroid_sources']
 
 
-@deprecated_renamed_argument('oversampling', None, '1.5')
-def centroid_com(data, mask=None, oversampling=1):
+def centroid_com(data, mask=None):
     """
     Calculate the centroid of an n-dimensional array as its "center of
     mass" determined from moments.
@@ -35,12 +33,6 @@ def centroid_com(data, mask=None, oversampling=1):
         A boolean mask, with the same shape as ``data``, where a `True`
         value indicates the corresponding element of ``data`` is masked.
 
-    oversampling : int or array_like (int)
-        Deprecated.
-        The integer oversampling factor(s). If ``oversampling`` is a
-        scalar then it will be used for both axes. If ``oversampling``
-        has two elements, they must be in ``(y, x)`` order.
-
     Returns
     -------
     centroid : `~numpy.ndarray`
@@ -53,16 +45,14 @@ def centroid_com(data, mask=None, oversampling=1):
         mask = np.asarray(mask, dtype=bool)
         if data.shape != mask.shape:
             raise ValueError('data and mask must have the same shape.')
-        data[mask] = 0.
-
-    oversampling = as_pair('oversampling', oversampling, lower_bound=(0, 1))
+        data[mask] = 0.0
 
     badmask = ~np.isfinite(data)
     if np.any(badmask):
         warnings.warn('Input data contains non-finite values (e.g., NaN or '
                       'inf) that were automatically masked.',
                       AstropyUserWarning)
-        data[badmask] = 0.
+        data[badmask] = 0.0
 
     total = np.sum(data)
     if total == 0:
@@ -71,7 +61,7 @@ def centroid_com(data, mask=None, oversampling=1):
     indices = np.ogrid[tuple(slice(0, i) for i in data.shape)]
 
     # note the output array is reversed to give (x, y) order
-    return np.array([np.sum(indices[axis] * data) / total / oversampling[axis]
+    return np.array([np.sum(indices[axis] * data) / total
                      for axis in range(data.ndim)])[::-1]
 
 
@@ -101,7 +91,7 @@ def centroid_quadratic(data, xpeak=None, ypeak=None, fit_boxsize=5,
 
     Parameters
     ----------
-    data : numpy.ndarray
+    data : `~numpy.ndarray`
         Image data.
 
     xpeak, ypeak : float or `None`, optional
@@ -143,6 +133,18 @@ def centroid_quadratic(data, xpeak=None, ypeak=None, fit_boxsize=5,
     Hogg (2016) <https://arxiv.org/abs/1610.05873>`_ for their 2D
     second-order polynomial centroiding method.
 
+    Because this centroid is based on fitting data, it can fail for many
+    reasons, returning (np.nan, np.nan):
+
+        * quadratic fit failed
+        * quadratic fit does not have a maximum
+        * quadratic fit maximum falls outside image
+        * not enough unmasked data points (6 are required)
+
+    Also note that a fit is not performed if the maximum data value is
+    at the edge of the data. In this case, the position of the maximum
+    pixel will be returned.
+
     References
     ----------
     .. [1] Vakili and Hogg 2016; arXiv:1610.05873
