@@ -6,35 +6,34 @@ Tests for the core module.
 import itertools
 from contextlib import nullcontext
 
-from astropy.modeling.models import Gaussian2D
-from astropy.utils.exceptions import (AstropyUserWarning,
-                                      AstropyDeprecationWarning)
 import numpy as np
-from numpy.testing import assert_allclose
 import pytest
+from astropy.modeling.models import Gaussian2D
+from astropy.utils.exceptions import AstropyUserWarning
+from numpy.testing import assert_allclose
 
-from ..core import centroid_com, centroid_quadratic, centroid_sources
-from ..gaussian import centroid_1dg, centroid_2dg
-from ...utils._optional_deps import HAS_SCIPY  # noqa
-
+from photutils.centroids.core import (centroid_com, centroid_quadratic,
+                                      centroid_sources)
+from photutils.centroids.gaussian import centroid_1dg, centroid_2dg
+from photutils.utils._optional_deps import HAS_SCIPY
 
 XCEN = 25.7
 YCEN = 26.2
 XSTDS = [3.2, 4.0]
 YSTDS = [5.7, 4.1]
-THETAS = np.array([30., 45.]) * np.pi / 180.
+THETAS = np.array([30.0, 45.0]) * np.pi / 180.0
 
 DATA = np.zeros((3, 3))
-DATA[0:2, 1] = 1.
-DATA[1, 0:2] = 1.
-DATA[1, 1] = 2.
+DATA[0:2, 1] = 1.0
+DATA[1, 0:2] = 1.0
+DATA[1, 1] = 2.0
 
 CENTROID_FUNCS = (centroid_com, centroid_quadratic, centroid_1dg,
                   centroid_2dg)
 
 
 # NOTE: the fitting routines in astropy use scipy.optimize
-@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 @pytest.mark.parametrize(('x_std', 'y_std', 'theta'),
                          list(itertools.product(XSTDS, YSTDS, THETAS)))
 def test_centroid_com(x_std, y_std, theta):
@@ -43,35 +42,23 @@ def test_centroid_com(x_std, y_std, theta):
     y, x = np.mgrid[0:50, 0:47]
     data = model(x, y)
     xc, yc = centroid_com(data)
-    assert_allclose((xc, yc), (XCEN, YCEN), rtol=0, atol=1.e-3)
+    assert_allclose((xc, yc), (XCEN, YCEN), rtol=0, atol=1.0e-3)
 
     xc, yc = centroid_quadratic(data)
     assert_allclose((xc, yc), (XCEN, YCEN), rtol=0, atol=0.015)
 
     # test with mask
     mask = np.zeros(data.shape, dtype=bool)
-    data[10, 10] = 1.e5
+    data[10, 10] = 1.0e5
     mask[10, 10] = True
     xc, yc = centroid_com(data, mask=mask)
-    assert_allclose((xc, yc), (XCEN, YCEN), rtol=0, atol=1.e-3)
+    assert_allclose((xc, yc), (XCEN, YCEN), rtol=0, atol=1.0e-3)
 
     xc, yc = centroid_quadratic(data, mask=mask)
     assert_allclose((xc, yc), (XCEN, YCEN), rtol=0, atol=0.015)
 
-    # test with oversampling
-    with pytest.warns(AstropyDeprecationWarning):
-        for oversampling in [4, (6, 4)]:
-            if not hasattr(oversampling, '__len__'):
-                _oversampling = (oversampling, oversampling)
-            else:
-                _oversampling = oversampling
-            xc, yc = centroid_com(data, mask=mask, oversampling=oversampling)
 
-            desired = [XCEN / _oversampling[1], YCEN / _oversampling[0]]
-            assert_allclose((xc, yc), desired, rtol=0, atol=1.e-3)
-
-
-@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 @pytest.mark.parametrize('use_mask', [True, False])
 def test_centroid_com_nan_withmask(use_mask):
     xc_ref = 24.7
@@ -93,7 +80,7 @@ def test_centroid_com_nan_withmask(use_mask):
 
     with ctx as warnlist:
         xc, yc = centroid_com(data, mask=mask)
-        assert_allclose(xc, xc_ref, rtol=0, atol=1.e-3)
+        assert_allclose(xc, xc_ref, rtol=0, atol=1.0e-3)
         assert yc > yc_ref
         if nwarn == 1:
             assert len(warnlist) == nwarn
@@ -106,17 +93,15 @@ def test_centroid_com_nan_withmask(use_mask):
         assert len(warnlist) == 1
 
 
-@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_centroid_com_invalid_inputs():
     data = np.zeros((4, 4))
     mask = np.zeros((2, 2), dtype=bool)
     with pytest.raises(ValueError):
         centroid_com(data, mask=mask)
-    with pytest.warns(AstropyDeprecationWarning), pytest.raises(ValueError):
-        centroid_com(data, oversampling=-1)
 
 
-@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_centroid_quadratic_xypeak():
     data = np.zeros((11, 11))
     data[5, 5] = 100
@@ -141,7 +126,7 @@ def test_centroid_quadratic_xypeak():
         centroid_quadratic(data, xpeak=15, ypeak=15)
 
 
-@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_centroid_quadratic_npts():
     data = np.zeros((3, 3))
     data[1, 1] = 1
@@ -153,7 +138,7 @@ def test_centroid_quadratic_npts():
         centroid_quadratic(data, mask=mask)
 
 
-@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_centroid_quadratic_invalid_inputs():
     data = np.zeros((4, 4))
     mask = np.zeros((2, 2), dtype=bool)
@@ -171,7 +156,7 @@ def test_centroid_quadratic_invalid_inputs():
         centroid_quadratic(data, mask=mask)
 
 
-@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_centroid_quadratic_edge():
     data = np.zeros((11, 11))
     data[1, 1] = 100
@@ -191,7 +176,7 @@ def test_centroid_quadratic_edge():
     assert_allclose(xycen, (0, 0))
 
 
-@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 class TestCentroidSources:
     def setup_class(self):
         ysize = 50
@@ -210,7 +195,7 @@ class TestCentroidSources:
 
     @staticmethod
     def test_centroid_sources():
-        theta = np.pi / 6.
+        theta = np.pi / 6.0
         model = Gaussian2D(2.4, XCEN, YCEN, x_stddev=3.2, y_stddev=5.7,
                            theta=theta)
         y, x = np.mgrid[0:50, 0:47]
@@ -218,8 +203,8 @@ class TestCentroidSources:
         error = np.ones(data.shape, dtype=float)
         mask = np.zeros(data.shape, dtype=bool)
         mask[10, 10] = True
-        xpos = [25.]
-        ypos = [26.]
+        xpos = [25.0]
+        ypos = [26.0]
         xc, yc = centroid_sources(data, xpos, ypos, box_size=21, mask=mask)
         assert_allclose(xc, (25.67,), atol=1e-1)
         assert_allclose(yc, (26.18,), atol=1e-1)
@@ -242,6 +227,7 @@ class TestCentroidSources:
 
         def test_func(data):
             return data
+
         with pytest.raises(ValueError):
             centroid_sources(data, [25], 26, centroid_func=test_func)
 
@@ -348,8 +334,8 @@ class TestCentroidSources:
                                   centroid_func=centroid_1dg)
         xycen2 = centroid_sources(self.data, xpos=25, ypos=25, error=None,
                                   centroid_func=centroid_2dg)
-        assert_allclose(xycen1, ([25], [25]), atol=1.e-3)
-        assert_allclose(xycen2, ([25], [25]), atol=1.e-3)
+        assert_allclose(xycen1, ([25], [25]), atol=1.0e-3)
+        assert_allclose(xycen2, ([25], [25]), atol=1.0e-3)
 
     def test_xypeaks_none(self):
         xycen1 = centroid_sources(self.data, xpos=25, ypos=25, error=None,
@@ -361,6 +347,6 @@ class TestCentroidSources:
         xycen3 = centroid_sources(self.data, xpos=25, ypos=25, error=None,
                                   xpeak=None, ypeak=None,
                                   centroid_func=centroid_quadratic)
-        assert_allclose(xycen1, ([25], [25]), atol=1.e-3)
-        assert_allclose(xycen2, ([25], [25]), atol=1.e-3)
-        assert_allclose(xycen3, ([25], [25]), atol=1.e-3)
+        assert_allclose(xycen1, ([25], [25]), atol=1.0e-3)
+        assert_allclose(xycen2, ([25], [25]), atol=1.0e-3)
+        assert_allclose(xycen3, ([25], [25]), atol=1.0e-3)
