@@ -18,15 +18,15 @@ def pytest_configure(config):
         # Customize the following lines to add/remove entries from the
         # list of packages for which version numbers are displayed when
         # running the tests.
-        PYTEST_HEADER_MODULES['Cython'] = 'Cython'  # noqa
-        PYTEST_HEADER_MODULES['Numpy'] = 'numpy'  # noqa
-        PYTEST_HEADER_MODULES['Astropy'] = 'astropy'  # noqa
-        PYTEST_HEADER_MODULES['Scipy'] = 'scipy'  # noqa
-        PYTEST_HEADER_MODULES['Matplotlib'] = 'matplotlib'  # noqa
-        PYTEST_HEADER_MODULES['scikit-image'] = 'skimage'  # noqa
-        PYTEST_HEADER_MODULES['scikit-learn'] = 'sklearn'  # noqa
-        PYTEST_HEADER_MODULES.pop('Pandas', None)  # noqa
-        PYTEST_HEADER_MODULES.pop('h5py', None)  # noqa
+        PYTEST_HEADER_MODULES['Cython'] = 'Cython'
+        PYTEST_HEADER_MODULES['Numpy'] = 'numpy'
+        PYTEST_HEADER_MODULES['Astropy'] = 'astropy'
+        PYTEST_HEADER_MODULES['Scipy'] = 'scipy'
+        PYTEST_HEADER_MODULES['Matplotlib'] = 'matplotlib'
+        PYTEST_HEADER_MODULES['scikit-image'] = 'skimage'
+        PYTEST_HEADER_MODULES['scikit-learn'] = 'sklearn'
+        PYTEST_HEADER_MODULES.pop('Pandas', None)
+        PYTEST_HEADER_MODULES.pop('h5py', None)
 
         from photutils import __version__
         TESTED_VERSIONS['photutils'] = __version__
