@@ -2,19 +2,20 @@
 """
 This module implements the IRAFStarFinder class.
 """
+
 import inspect
 import warnings
 
+import numpy as np
 from astropy.nddata import extract_array
 from astropy.table import QTable
 from astropy.utils import lazyproperty
-import numpy as np
 
-from .core import StarFinderBase, _StarFinderKernel
-from ..utils._convolution import _filter_data
-from ..utils._misc import _get_version_info
-from ..utils._moments import _moments, _moments_central
-from ..utils.exceptions import NoDetectionsWarning
+from photutils.detection.core import StarFinderBase, _StarFinderKernel
+from photutils.utils._convolution import _filter_data
+from photutils.utils._misc import _get_version_info
+from photutils.utils._moments import _moments, _moments_central
+from photutils.utils.exceptions import NoDetectionsWarning
 
 __all__ = ['IRAFStarFinder']
 
@@ -342,8 +343,10 @@ class _IRAFStarFinderCatalog:
         """
         Return all lazyproperties (even in superclasses).
         """
+
         def islazyproperty(obj):
             return isinstance(obj, lazyproperty)
+
         return [i[0] for i in inspect.getmembers(self.__class__,
                                                  predicate=islazyproperty)]
 
@@ -357,7 +360,7 @@ class _IRAFStarFinderCatalog:
             skymask = ~self.kernel.mask.astype(bool)  # 1=sky, 0=obj
             nsky = np.count_nonzero(skymask)
             axis = (1, 2)
-            if nsky == 0.:
+            if nsky == 0.0:
                 sky = (np.max(self.cutout_data_nosub, axis=axis)
                        - np.max(self.cutout_convdata, axis=axis))
             else:
