@@ -3,16 +3,16 @@
 Tests for the peakfinder module.
 """
 
-from astropy.tests.helper import assert_quantity_allclose
 import numpy as np
-from numpy.testing import assert_array_equal
 import pytest
+from astropy.tests.helper import assert_quantity_allclose
+from numpy.testing import assert_array_equal
 
-from ..peakfinder import find_peaks
-from ...centroids import centroid_com
-from ...datasets import make_4gaussians_image, make_gwcs, make_wcs
-from ...utils.exceptions import NoDetectionsWarning
-from ...utils._optional_deps import HAS_GWCS, HAS_SCIPY  # noqa
+from photutils.centroids import centroid_com
+from photutils.datasets import make_4gaussians_image, make_gwcs, make_wcs
+from photutils.detection.peakfinder import find_peaks
+from photutils.utils._optional_deps import HAS_GWCS, HAS_SCIPY
+from photutils.utils.exceptions import NoDetectionsWarning
 
 PEAKDATA = np.array([[1, 0, 0], [0, 0, 0], [0, 0, 1]]).astype(float)
 PEAKREF1 = np.array([[0, 0], [2, 2]])
@@ -21,21 +21,21 @@ IMAGE = make_4gaussians_image()
 FITSWCS = make_wcs(IMAGE.shape)
 
 
-@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 class TestFindPeaks:
     def test_box_size(self):
         """Test with box_size."""
         tbl = find_peaks(PEAKDATA, 0.1, box_size=3)
         assert_array_equal(tbl['x_peak'], PEAKREF1[:, 1])
         assert_array_equal(tbl['y_peak'], PEAKREF1[:, 0])
-        assert_array_equal(tbl['peak_value'], [1., 1.])
+        assert_array_equal(tbl['peak_value'], [1.0, 1.0])
 
     def test_footprint(self):
         """Test with footprint."""
         tbl = find_peaks(PEAKDATA, 0.1, footprint=np.ones((3, 3)))
         assert_array_equal(tbl['x_peak'], PEAKREF1[:, 1])
         assert_array_equal(tbl['y_peak'], PEAKREF1[:, 0])
-        assert_array_equal(tbl['peak_value'], [1., 1.])
+        assert_array_equal(tbl['peak_value'], [1.0, 1.0])
 
     def test_mask(self):
         """Test with mask."""
@@ -72,7 +72,7 @@ class TestFindPeaks:
 
     def test_box_size_int(self):
         """Test non-integer box_size."""
-        tbl1 = find_peaks(PEAKDATA, 0.1, box_size=5.)
+        tbl1 = find_peaks(PEAKDATA, 0.1, box_size=5.0)
         tbl2 = find_peaks(PEAKDATA, 0.1, box_size=5.5)
         assert_array_equal(tbl1, tbl2)
 
@@ -89,7 +89,7 @@ class TestFindPeaks:
         for column in columns:
             assert column in tbl.colnames
 
-    @pytest.mark.skipif('not HAS_GWCS')
+    @pytest.mark.skipif(not HAS_GWCS, reason='gwcs is required')
     def test_gwcs(self):
         """Test with gwcs."""
         columns = ['skycoord_peak', 'skycoord_centroid']
@@ -99,7 +99,7 @@ class TestFindPeaks:
         for column in columns:
             assert column in tbl.colnames
 
-    @pytest.mark.skipif('not HAS_GWCS')
+    @pytest.mark.skipif(not HAS_GWCS, reason='gwcs is required')
     def test_wcs_values(self):
         gwcs_obj = make_gwcs(IMAGE.shape)
         tbl1 = find_peaks(IMAGE, 100, wcs=FITSWCS, centroid_func=centroid_com)
@@ -114,7 +114,7 @@ class TestFindPeaks:
         """Test for empty output table when data is constant."""
         data = np.ones((10, 10))
         with pytest.warns(NoDetectionsWarning, match='Input data is constant'):
-            tbl = find_peaks(data, 0.)
+            tbl = find_peaks(data, 0.0)
             assert tbl is None
 
     def test_no_peaks(self):
@@ -143,4 +143,4 @@ class TestFindPeaks:
         """Test that data with NaNs does not issue Runtime warning."""
         data = np.copy(PEAKDATA)
         data[1, 1] = np.nan
-        find_peaks(data, 0.)
+        find_peaks(data, 0.0)
