@@ -5,16 +5,17 @@ This module provides a class to fit elliptical isophotes.
 
 import warnings
 
-from astropy.utils.exceptions import AstropyUserWarning
 import numpy as np
+from astropy.utils.exceptions import AstropyUserWarning
 
-from .fitter import (DEFAULT_CONVERGENCE, DEFAULT_FFLAG, DEFAULT_MAXGERR,
-                     DEFAULT_MAXIT, DEFAULT_MINIT, CentralEllipseFitter,
-                     EllipseFitter)
-from .geometry import EllipseGeometry
-from .integrator import BILINEAR
-from .isophote import Isophote, IsophoteList
-from .sample import CentralEllipseSample, EllipseSample
+from photutils.isophote.fitter import (DEFAULT_CONVERGENCE, DEFAULT_FFLAG,
+                                       DEFAULT_MAXGERR, DEFAULT_MAXIT,
+                                       DEFAULT_MINIT, CentralEllipseFitter,
+                                       EllipseFitter)
+from photutils.isophote.geometry import EllipseGeometry
+from photutils.isophote.integrator import BILINEAR
+from photutils.isophote.isophote import Isophote, IsophoteList
+from photutils.isophote.sample import CentralEllipseSample, EllipseSample
 
 __all__ = ['Ellipse']
 
@@ -183,7 +184,7 @@ class Ellipse:
         else:
             _x0 = image.shape[1] / 2
             _y0 = image.shape[0] / 2
-            self._geometry = EllipseGeometry(_x0, _y0, 10., eps=0.2,
+            self._geometry = EllipseGeometry(_x0, _y0, 10.0, eps=0.2,
                                              pa=np.pi / 2)
         self.set_threshold(threshold)
 
@@ -198,10 +199,10 @@ class Ellipse:
         """
         self._geometry.centerer_threshold = threshold
 
-    def fit_image(self, sma0=None, minsma=0., maxsma=None, step=0.1,
+    def fit_image(self, sma0=None, minsma=0.0, maxsma=None, step=0.1,
                   conver=DEFAULT_CONVERGENCE, minit=DEFAULT_MINIT,
                   maxit=DEFAULT_MAXIT, fflag=DEFAULT_FFLAG,
-                  maxgerr=DEFAULT_MAXGERR, sclip=3., nclip=0,
+                  maxgerr=DEFAULT_MAXGERR, sclip=3.0, nclip=0,
                   integrmode=BILINEAR, linear=None, maxrit=None,
                   fix_center=False, fix_pa=False, fix_eps=False):
         # This parameter list is quite large and should in principle be
@@ -382,7 +383,7 @@ class Ellipse:
             if self._geometry:
                 sma = self._geometry.sma
             else:
-                sma = 10.
+                sma = 10.0
         else:
             sma = sma0
 
@@ -416,7 +417,7 @@ class Ellipse:
                                          isophote_list=isophote_list)
 
             # check for failed fit.
-            if (isophote.stop_code < 0 or isophote.stop_code == 1):
+            if isophote.stop_code < 0 or isophote.stop_code == 1:
                 # in case the fit failed right at the outset, return an
                 # empty list. This is the usual case when the user
                 # provides initial guesses that are too way off to enable
@@ -506,7 +507,7 @@ class Ellipse:
     def fit_isophote(self, sma, step=0.1, conver=DEFAULT_CONVERGENCE,
                      minit=DEFAULT_MINIT, maxit=DEFAULT_MAXIT,
                      fflag=DEFAULT_FFLAG, maxgerr=DEFAULT_MAXGERR,
-                     sclip=3., nclip=0, integrmode=BILINEAR,
+                     sclip=3.0, nclip=0, integrmode=BILINEAR,
                      linear=False, maxrit=None, noniterate=False,
                      going_inwards=False, isophote_list=None):
         """
@@ -649,7 +650,7 @@ class Ellipse:
     def _iterative(self, sma, step, linear, geometry, sclip, nclip,
                    integrmode, conver, minit, maxit, fflag, maxgerr,
                    going_inwards=False):
-        if sma > 0.:
+        if sma > 0.0:
             # iterative fitter
             sample = EllipseSample(self.image, sma, astep=step, sclip=sclip,
                                    nclip=nclip, linear_growth=linear,
@@ -694,7 +695,7 @@ class Ellipse:
 
             # we take the opportunity to change an eventual
             # negative stop code to its' positive equivalent.
-            code = (5 if isophote.stop_code < 0 else isophote.stop_code)
+            code = 5 if isophote.stop_code < 0 else isophote.stop_code
 
             # build new instance so it can have its attributes
             # populated from the updated sample attributes.
