@@ -3,21 +3,20 @@
 Tests for the fitter module.
 """
 
-from astropy.io import fits
 import numpy as np
-from numpy.testing import assert_allclose
 import pytest
+from astropy.io import fits
+from numpy.testing import assert_allclose
 
-from .make_test_data import make_test_image
-from ..fitter import CentralEllipseFitter, EllipseFitter
-from ..geometry import EllipseGeometry
-from ..harmonics import fit_first_and_second_harmonics
-from ..integrator import MEAN
-from ..isophote import Isophote
-from ..sample import CentralEllipseSample, EllipseSample
-from ...datasets import get_path
-from ...utils._optional_deps import HAS_SCIPY  # noqa
-
+from photutils.datasets import get_path
+from photutils.isophote.fitter import CentralEllipseFitter, EllipseFitter
+from photutils.isophote.geometry import EllipseGeometry
+from photutils.isophote.harmonics import fit_first_and_second_harmonics
+from photutils.isophote.integrator import MEAN
+from photutils.isophote.isophote import Isophote
+from photutils.isophote.sample import CentralEllipseSample, EllipseSample
+from photutils.isophote.tests.make_test_data import make_test_image
+from photutils.utils._optional_deps import HAS_SCIPY
 
 DATA = make_test_image(seed=0)
 DEFAULT_POS = 256
@@ -26,17 +25,17 @@ DEFAULT_FIX = np.array([False, False, False, False])
 
 
 def test_gradient():
-    sample = EllipseSample(DATA, 40.)
+    sample = EllipseSample(DATA, 40.0)
     sample.update(DEFAULT_FIX)
 
     assert_allclose(sample.mean, 200.02, atol=0.01)
     assert_allclose(sample.gradient, -4.222, atol=0.001)
     assert_allclose(sample.gradient_error, 0.0003, atol=0.0001)
-    assert_allclose(sample.gradient_relative_error, 7.45e-05, atol=1.e-5)
+    assert_allclose(sample.gradient_relative_error, 7.45e-05, atol=1.0e-5)
     assert_allclose(sample.sector_area, 2.00, atol=0.01)
 
 
-@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_fitting_raw():
     """
     This test performs a raw (no EllipseFitter), 1-step correction in
@@ -45,7 +44,7 @@ def test_fitting_raw():
 
     # pick first guess ellipse that is off in just
     # one of the parameters (eps).
-    sample = EllipseSample(DATA, 40., eps=2 * 0.2)
+    sample = EllipseSample(DATA, 40.0, eps=2 * 0.2)
     sample.update(DEFAULT_FIX)
     s = sample.extract()
 
@@ -57,7 +56,7 @@ def test_fitting_raw():
     assert abs(b2) > abs(b1)
     assert abs(b2) > abs(a2)
 
-    correction = (b2 * 2. * (1. - sample.geometry.eps)
+    correction = (b2 * 2.0 * (1.0 - sample.geometry.eps)
                   / sample.geometry.sma / sample.gradient)
     new_eps = sample.geometry.eps - correction
 
@@ -65,9 +64,9 @@ def test_fitting_raw():
     assert_allclose(new_eps, 0.21, atol=0.01)
 
 
-@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_fitting_small_radii():
-    sample = EllipseSample(DATA, 2.)
+    sample = EllipseSample(DATA, 2.0)
     fitter = EllipseFitter(sample)
     isophote = fitter.fit()
 
@@ -75,10 +74,10 @@ def test_fitting_small_radii():
     assert isophote.ndata == 13
 
 
-@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_fitting_eps():
     # initial guess is off in the eps parameter
-    sample = EllipseSample(DATA, 40., eps=2 * 0.2)
+    sample = EllipseSample(DATA, 40.0, eps=2 * 0.2)
     fitter = EllipseFitter(sample)
     isophote = fitter.fit()
 
@@ -88,7 +87,7 @@ def test_fitting_eps():
     assert g.eps <= 0.21
 
 
-@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_fitting_pa():
     data = make_test_image(pa=np.pi / 4, noise=0.01, seed=0)
 
@@ -102,7 +101,7 @@ def test_fitting_pa():
     assert g.pa <= (np.pi / 4 + 0.05)
 
 
-@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_fitting_xy():
     pos = DEFAULT_POS - 5
     data = make_test_image(x0=pos, y0=pos, seed=0)
@@ -119,7 +118,7 @@ def test_fitting_xy():
     assert g.y0 <= (pos + 1)
 
 
-@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_fitting_all():
     # build test image that is off from the defaults
     # assumed by the EllipseSample constructor.
@@ -127,7 +126,7 @@ def test_fitting_all():
     angle = np.pi / 4
     eps = 2 * 0.2
     data = make_test_image(x0=pos, y0=pos, eps=eps, pa=angle, seed=0)
-    sma = 60.
+    sma = 60.0
 
     # initial guess is off in all parameters. We find that the initial
     # guesses, especially for position angle, must be kinda close to the
@@ -157,7 +156,7 @@ def test_fitting_all():
 
 
 @pytest.mark.remote_data
-@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 class TestM51:
     def setup_class(self):
         path = get_path('isophote/M51.fits', location='photutils-datasets',
@@ -181,7 +180,7 @@ class TestM51:
 
         # sample taken in high SNR region
         sample = EllipseSample(self.data, 21.44, eps=0.18,
-                               position_angle=(36. / 180. * np.pi))
+                               position_angle=(36.0 / 180.0 * np.pi))
         fitter = EllipseFitter(sample)
         isophote = fitter.fit()
 
@@ -201,7 +200,7 @@ class TestM51:
         # sample taken at the outskirts of the image, so many
         # data points lay outside the image frame. This checks
         # for the presence of gaps in the sample arrays.
-        sample = EllipseSample(self.data, 330., eps=0.2,
+        sample = EllipseSample(self.data, 330.0, eps=0.2,
                                position_angle=((90) / 180 * np.pi),
                                integrmode='median')
         fitter = EllipseFitter(sample)
@@ -221,5 +220,5 @@ class TestM51:
         # the central pixel intensity is about 3% larger than
         # found by the spp code.
         assert isophote.ndata == 1
-        assert isophote.intens <= 7560.
-        assert isophote.intens >= 7550.
+        assert isophote.intens <= 7560.0
+        assert isophote.intens >= 7550.0
