@@ -3,35 +3,35 @@
 Tests for the fourier module.
 """
 
+import numpy as np
+import pytest
 from astropy.modeling.fitting import LevMarLSQFitter
 from astropy.modeling.models import Gaussian2D
-import numpy as np
 from numpy.testing import assert_allclose
-import pytest
 
-from ..fourier import create_matching_kernel, resize_psf
-from ..windows import SplitCosineBellWindow
-from ....utils._optional_deps import HAS_SCIPY  # noqa
+from photutils.psf.matching.fourier import create_matching_kernel, resize_psf
+from photutils.psf.matching.windows import SplitCosineBellWindow
+from photutils.utils._optional_deps import HAS_SCIPY
 
 
-@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_resize_psf():
     psf1 = np.ones((5, 5))
     psf2 = resize_psf(psf1, 0.1, 0.05)
     assert psf2.shape == (10, 10)
 
 
-@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_create_matching_kernel():
     """Test with noiseless 2D Gaussians."""
 
     size = 25
-    cen = (size - 1) / 2.
+    cen = (size - 1) / 2.0
     y, x = np.mgrid[0:size, 0:size]
-    std1 = 3.
-    std2 = 5.
-    gm1 = Gaussian2D(1., cen, cen, std1, std1)
-    gm2 = Gaussian2D(1., cen, cen, std2, std2)
+    std1 = 3.0
+    std2 = 5.0
+    gm1 = Gaussian2D(1.0, cen, cen, std1, std1)
+    gm2 = Gaussian2D(1.0, cen, cen, std2, std2)
     g1 = gm1(x, y)
     g2 = gm2(x, y)
     g1 /= g1.sum()
