@@ -5,21 +5,22 @@ This module provides classes to perform PSF-fitting photometry.
 
 import warnings
 
+import numpy as np
 from astropy.modeling.fitting import LevMarLSQFitter
-from astropy.nddata.utils import overlap_slices, NoOverlapError
+from astropy.nddata.utils import NoOverlapError, overlap_slices
 from astropy.stats import SigmaClip, gaussian_sigma_to_fwhm
 from astropy.table import Column, QTable, hstack, vstack
 from astropy.utils.exceptions import AstropyUserWarning
-import numpy as np
 
-from .groupstars import DAOGroup
-from .utils import (_extract_psf_fitting_names, get_grouped_psf_model,
-                    subtract_psf)
-from ..aperture import CircularAperture, aperture_photometry
-from ..background import MMMBackground
-from ..detection import DAOStarFinder
-from ..utils.exceptions import NoDetectionsWarning
-from ..utils._misc import _get_version_info
+from photutils.aperture import CircularAperture, aperture_photometry
+from photutils.background import MMMBackground
+from photutils.detection import DAOStarFinder
+from photutils.psf.groupstars import DAOGroup
+from photutils.psf.utils import (_extract_psf_fitting_names,
+                                 get_grouped_psf_model, subtract_psf)
+from photutils.utils._misc import _get_version_info
+from photutils.utils._optional_deps import HAS_TQDM
+from photutils.utils.exceptions import NoDetectionsWarning
 
 __all__ = ['BasicPSFPhotometry', 'IterativelySubtractedPSFPhotometry',
            'DAOPhotPSFPhotometry']
@@ -34,7 +35,7 @@ class BasicPSFPhotometry:
     GROUP, NSTAR, and SUBTRACT.  This implementation allows a flexible
     and customizable interface to perform photometry. For instance, one
     is able to use different implementations for grouping and finding
-    sources by using ``group_maker`` and ``finder`` respectivelly. In
+    sources by using ``group_maker`` and ``finder`` respectively. In
     addition, sky background estimation is performed by
     ``bkg_estimator``.
 
@@ -59,21 +60,19 @@ class BasicPSFPhotometry:
         background subtraction is performed.
     psf_model : `astropy.modeling.Fittable2DModel` instance
         PSF or PRF model to fit the data. Could be one of the models in
-        this package like `~photutils.psf.sandbox.DiscretePRF`,
-        `~photutils.psf.IntegratedGaussianPRF`, or any other suitable 2D
-        model.  This object needs to identify three parameters (position
-        of center in x and y coordinates and the flux) in order to set
-        them to suitable starting values for each fit. The names of
-        these parameters should be given as ``x_0``, ``y_0`` and
-        ``flux``.  `~photutils.psf.prepare_psf_model` can be used to
-        prepare any 2D model to match this assumption.
+        this package like `~photutils.psf.IntegratedGaussianPRF` or any
+        other suitable 2D model. This object needs to identify three
+        parameters (position of center in x and y coordinates and the
+        flux) in order to set them to suitable starting values for each
+        fit. The names of these parameters should be given as ``x_0``,
+        ``y_0`` and ``flux``. `~photutils.psf.prepare_psf_model` can be
+        used to prepare any 2D model to match this assumption.
     fitshape : int or length-2 array-like
-        Rectangular shape around the center of a star which will be
-        used to collect the data to do the fitting. Can be an integer
-        to be the same along both axes. For example, 5 is the same as
-        (5, 5), which means to fit only at the following relative pixel
-        positions: [-2, -1, 0, 1, 2]. Each element of ``fitshape`` must
-        be an odd number.
+        Rectangular shape around the center of a star that will be
+        used to define the PSF-fitting region. If ``fitshape`` is a
+        scalar then a square shape of size ``fitshape`` will be used.
+        If ``fitshape`` has two elements, they must be in ``(ny, nx)``
+        order. Each element of ``fitshape`` must be an odd number.
     finder : callable or instance of any \
             `~photutils.detection.StarFinderBase` subclasses or None
         ``finder`` should be able to identify stars, i.e., compute a
@@ -103,6 +102,13 @@ class BasicPSFPhotometry:
         List of additional columns for parameters derived by any of the
         intermediate fitting steps (e.g., ``finder``), such as roundness
         or sharpness.
+    subshape : `None`, int, or length-2 array-like
+        Rectangular shape around the center of a star that will be
+        used to define the PSF-subtraction region. If `None`, then
+        ``fitshape`` will be used. If ``subshape`` is a scalar then a
+        square shape of size ``subshape`` will be used. If ``subshape``
+        has two elements, they must be in ``(ny, nx)`` order. Each
+        element of ``subshape`` must be an odd number.
 
     Notes
     -----
@@ -128,7 +134,7 @@ class BasicPSFPhotometry:
 
     def __init__(self, group_maker, bkg_estimator, psf_model, fitshape, *,
                  finder=None, fitter=LevMarLSQFitter(), aperture_radius=None,
-                 extra_output_cols=None):
+                 extra_output_cols=None, subshape=None):
         self.group_maker = group_maker
         self.bkg_estimator = bkg_estimator
         self.psf_model = psf_model
@@ -140,6 +146,7 @@ class BasicPSFPhotometry:
         self._pars_to_output = None
         self._residual_image = None
         self._extra_output_cols = extra_output_cols
+        self.subshape = subshape
 
     @property
     def fitshape(self):
@@ -167,6 +174,36 @@ class BasicPSFPhotometry:
             raise ValueError('fitshape must have two dimensions, '
                              f'received fitshape={value}')
 
+    @property
+    def subshape(self):
+        return self._subshape
+
+    @subshape.setter
+    def subshape(self, value):
+        if value is None:
+            self._subshape = self._fitshape
+            return
+
+        value = np.asarray(value)
+
+        # assume a lone value should mean both axes
+        if value.shape == ():
+            value = np.array((value, value))
+
+        if value.size == 2:
+            if np.all(value) > 0:
+                if np.all(value % 2) == 1:
+                    self._subshape = tuple(value)
+                else:
+                    raise ValueError('subshape must be odd integer-valued, '
+                                     f'received subshape={value}')
+            else:
+                raise ValueError('subshape must have positive elements, '
+                                 f'received subshape={value}')
+        else:
+            raise ValueError('subshape must have two dimensions, '
+                             f'received subshape={value}')
+
     @property
     def aperture_radius(self):
         return self._aperture_radius
@@ -244,14 +281,17 @@ class BasicPSFPhotometry:
                               'automatically ignored.', AstropyUserWarning)
         return mask
 
-    def __call__(self, image, *, mask=None, init_guesses=None):
+    def __call__(self, image, *, mask=None, init_guesses=None,
+                 progress_bar=False):
         """
         Perform PSF photometry. See `do_photometry` for more details
         including the `__call__` signature.
         """
-        return self.do_photometry(image, mask=mask, init_guesses=init_guesses)
+        return self.do_photometry(image, mask=mask, init_guesses=init_guesses,
+                                  progress_bar=progress_bar)
 
-    def do_photometry(self, image, *, mask=None, init_guesses=None):
+    def do_photometry(self, image, *, mask=None, init_guesses=None,
+                      progress_bar=False):
         """
         Perform PSF photometry in ``image``.
 
@@ -288,6 +328,12 @@ class BasicPSFPhotometry:
             A boolean mask with the same shape as ``image``, where
             a `True` value indicates the corresponding element of
             ``image`` is masked.
+        progress_bar : bool, optional
+            Whether to display a progress bar when fitting the
+            star groups. The progress bar requires that the `tqdm
+            <https://tqdm.github.io/>`_ optional dependency be
+            installed. Note that the progress bar does not currently
+            work in the Jupyter console due to limitations in ``tqdm``.
 
         Returns
         -------
@@ -383,8 +429,8 @@ class BasicPSFPhotometry:
         else:
             star_groups = self.group_maker(init_guesses)
 
-        output_tab, self._residual_image = self.nstar(image, star_groups,
-                                                      mask=mask)
+        output_tab, self._residual_image = self.nstar(
+            image, star_groups, mask=mask, progress_bar=progress_bar)
         star_groups = star_groups.group_by('group_id')
 
         if hasattr(output_tab, 'update'):  # requires Astropy >= 5.0
@@ -402,7 +448,7 @@ class BasicPSFPhotometry:
 
         return star_groups
 
-    def nstar(self, image, star_groups, *, mask=None):
+    def nstar(self, image, star_groups, *, mask=None, progress_bar=False):
         """
         Fit, as appropriate, a compound or single model to the given
         ``star_groups``. Groups are fitted sequentially from the
@@ -429,6 +475,13 @@ class BasicPSFPhotometry:
             a `True` value indicates the corresponding element of
             ``image`` is masked.
 
+        progress_bar : bool, optional
+            Use a progress bar to show progress over the star groups.
+            The progress bar requires that the `tqdm
+            <https://tqdm.github.io/>`_ optional dependency be
+            installed. Note that the progress bar does not currently
+            work in the Jupyter console due to limitations in ``tqdm``.
+
         Returns
         -------
         result_tab : `~astropy.table.QTable`
@@ -449,7 +502,13 @@ class BasicPSFPhotometry:
         y, x = np.indices(image.shape)
 
         star_groups = star_groups.group_by('group_id')
-        for group in star_groups.groups:
+        group_iter = star_groups.groups
+        if progress_bar and HAS_TQDM:
+            from tqdm.auto import tqdm  # pragma: no cover
+
+            group_iter = tqdm(group_iter, desc='Star Group')  # pragma: no cover
+
+        for group in group_iter:
             group_psf = get_grouped_psf_model(self.psf_model, group,
                                               self._pars_to_set)
             usepixel = np.zeros_like(image, dtype=bool)
@@ -476,7 +535,7 @@ class BasicPSFPhotometry:
             # do not subtract if the fitting did not go well
             try:
                 image = subtract_psf(image, self.psf_model, param_table,
-                                     subshape=self.fitshape)
+                                     subshape=self.subshape)
             except NoOverlapError:
                 pass
 
@@ -545,9 +604,14 @@ class BasicPSFPhotometry:
         k = 0
         n_fit_params = len(unc_tab.colnames)
         param_cov = self.fitter.fit_info.get('param_cov', None)
-        for i in range(star_group_size):
-            unc_tab[i] = np.sqrt(np.diag(param_cov))[k: k + n_fit_params]
-            k = k + n_fit_params
+
+        # variance is sometimes returned as a negative value
+        # ignore sqrt(negative value) RuntimeWarnings
+        with warnings.catch_warnings():
+            warnings.simplefilter('ignore', RuntimeWarning)
+            for i in range(star_group_size):
+                unc_tab[i] = np.sqrt(np.diag(param_cov))[k: k + n_fit_params]
+                k = k + n_fit_params
 
         return unc_tab
 
@@ -559,9 +623,8 @@ class BasicPSFPhotometry:
         ----------
         fit_model : `astropy.modeling.Fittable2DModel` instance
             PSF or PRF model to fit the data. Could be one of the models
-            in this package like `~photutils.psf.sandbox.DiscretePRF`,
-            `~photutils.psf.IntegratedGaussianPRF`, or any other
-            suitable 2D model.
+            in this package like `~photutils.psf.IntegratedGaussianPRF`
+            or any other suitable 2D model.
 
         star_group : `~astropy.table.Table`
             the star group instance.
@@ -631,21 +694,19 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
         background subtraction is performed.
     psf_model : `astropy.modeling.Fittable2DModel` instance
         PSF or PRF model to fit the data. Could be one of the models in
-        this package like `~photutils.psf.sandbox.DiscretePRF`,
-        `~photutils.psf.IntegratedGaussianPRF`, or any other suitable 2D
-        model.  This object needs to identify three parameters (position
-        of center in x and y coordinates and the flux) in order to set
-        them to suitable starting values for each fit. The names of
-        these parameters should be given as ``x_0``, ``y_0`` and
-        ``flux``.  `~photutils.psf.prepare_psf_model` can be used to
-        prepare any 2D model to match this assumption.
+        this package like `~photutils.psf.IntegratedGaussianPRF` or any
+        other suitable 2D model. This object needs to identify three
+        parameters (position of center in x and y coordinates and the
+        flux) in order to set them to suitable starting values for each
+        fit. The names of these parameters should be given as ``x_0``,
+        ``y_0`` and ``flux``. `~photutils.psf.prepare_psf_model` can be
+        used to prepare any 2D model to match this assumption.
     fitshape : int or length-2 array-like
-        Rectangular shape around the center of a star which will be
-        used to collect the data to do the fitting. Can be an integer
-        to be the same along both axes. For example, 5 is the same as
-        (5, 5), which means to fit only at the following relative pixel
-        positions: [-2, -1, 0, 1, 2]. Each element of ``fitshape`` must
-        be an odd number.
+        Rectangular shape around the center of a star that will be
+        used to define the PSF-fitting region. If ``fitshape`` is a
+        scalar then a square shape of size ``fitshape`` will be used.
+        If ``fitshape`` has two elements, they must be in ``(ny, nx)``
+        order. Each element of ``fitshape`` must be an odd number.
     finder : callable or instance of any \
             `~photutils.detection.StarFinderBase` subclasses
         ``finder`` should be able to identify stars, i.e., compute a
@@ -676,6 +737,13 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
         List of additional columns for parameters derived by any of the
         intermediate fitting steps (e.g., ``finder``), such as roundness
         or sharpness.
+    subshape : `None`, int, or length-2 array-like
+        Rectangular shape around the center of a star that will be
+        used to define the PSF-subtraction region. If `None`, then
+        ``fitshape`` will be used. If ``subshape`` is a scalar then a
+        square shape of size ``subshape`` will be used. If ``subshape``
+        has two elements, they must be in ``(ny, nx)`` order. Each
+        element of ``subshape`` must be an odd number.
 
     Notes
     -----
@@ -695,12 +763,13 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
 
     def __init__(self, group_maker, bkg_estimator, psf_model, fitshape,
                  finder, *, fitter=LevMarLSQFitter(), niters=3,
-                 aperture_radius=None, extra_output_cols=None):
+                 aperture_radius=None, extra_output_cols=None, subshape=None):
 
         super().__init__(group_maker, bkg_estimator, psf_model, fitshape,
                          finder=finder, fitter=fitter,
                          aperture_radius=aperture_radius,
-                         extra_output_cols=extra_output_cols)
+                         extra_output_cols=extra_output_cols,
+                         subshape=subshape)
         self.niters = niters
 
     @property
@@ -733,7 +802,8 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
                              "Detection section on photutils documentation.")
         self._finder = value
 
-    def do_photometry(self, image, *, mask=None, init_guesses=None):
+    def do_photometry(self, image, *, mask=None, init_guesses=None,
+                      progress_bar=False):
         """
         Perform PSF photometry in ``image``.
 
@@ -786,7 +856,8 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
 
         if init_guesses is not None:
             table = super().do_photometry(image, mask=mask,
-                                          init_guesses=init_guesses)
+                                          init_guesses=init_guesses,
+                                          progress_bar=progress_bar)
             table['iter_detected'] = np.ones(table['x_fit'].shape, dtype=int)
 
             # n_start = 2 because it starts in the second iteration
@@ -918,21 +989,19 @@ class DAOPhotPSFPhotometry(IterativelySubtractedPSFPhotometry):
         Gaussian kernel in units of pixels.
     psf_model : `astropy.modeling.Fittable2DModel` instance
         PSF or PRF model to fit the data. Could be one of the models in
-        this package like `~photutils.psf.sandbox.DiscretePRF`,
-        `~photutils.psf.IntegratedGaussianPRF`, or any other suitable 2D
-        model.  This object needs to identify three parameters (position
-        of center in x and y coordinates and the flux) in order to set
-        them to suitable starting values for each fit. The names of
-        these parameters should be given as ``x_0``, ``y_0`` and
-        ``flux``.  `~photutils.psf.prepare_psf_model` can be used to
-        prepare any 2D model to match this assumption.
+        this package like `~photutils.psf.IntegratedGaussianPRF` or any
+        other suitable 2D model. This object needs to identify three
+        parameters (position of center in x and y coordinates and the
+        flux) in order to set them to suitable starting values for each
+        fit. The names of these parameters should be given as ``x_0``,
+        ``y_0`` and ``flux``. `~photutils.psf.prepare_psf_model` can be
+        used to prepare any 2D model to match this assumption.
     fitshape : int or length-2 array-like
-        Rectangular shape around the center of a star which will be
-        used to collect the data to do the fitting. Can be an integer
-        to be the same along both axes. For example, 5 is the same as
-        (5, 5), which means to fit only at the following relative pixel
-        positions: [-2, -1, 0, 1, 2]. Each element of ``fitshape`` must
-        be an odd number.
+        Rectangular shape around the center of a star that will be
+        used to define the PSF-fitting region. If ``fitshape`` is a
+        scalar then a square shape of size ``fitshape`` will be used.
+        If ``fitshape`` has two elements, they must be in ``(ny, nx)``
+        order. Each element of ``fitshape`` must be an odd number.
     sigma : float, optional
         Number of standard deviations used to perform sigma clip with a
         `astropy.stats.SigmaClip` object.
@@ -975,6 +1044,13 @@ class DAOPhotPSFPhotometry(IterativelySubtractedPSFPhotometry):
         List of additional columns for parameters derived by any of the
         intermediate fitting steps (e.g., ``finder``), such as roundness
         or sharpness.
+    subshape : `None`, int, or length-2 array-like
+        Rectangular shape around the center of a star that will be
+        used to define the PSF-subtraction region. If `None`, then
+        ``fitshape`` will be used. If ``subshape`` is a scalar then a
+        square shape of size ``subshape`` will be used. If ``subshape``
+        has two elements, they must be in ``(ny, nx)`` order. Each
+        element of ``subshape`` must be an odd number.
 
     Notes
     -----
@@ -993,10 +1069,11 @@ class DAOPhotPSFPhotometry(IterativelySubtractedPSFPhotometry):
     """
 
     def __init__(self, crit_separation, threshold, fwhm, psf_model, fitshape,
-                 *, sigma=3., ratio=1.0, theta=0.0, sigma_radius=1.5,
+                 *, sigma=3.0, ratio=1.0, theta=0.0, sigma_radius=1.5,
                  sharplo=0.2, sharphi=1.0, roundlo=-1.0, roundhi=1.0,
                  fitter=LevMarLSQFitter(),
-                 niters=3, aperture_radius=None, extra_output_cols=None):
+                 niters=3, aperture_radius=None, extra_output_cols=None,
+                 subshape=None):
 
         self.crit_separation = crit_separation
         self.threshold = threshold
@@ -1022,4 +1099,5 @@ class DAOPhotPSFPhotometry(IterativelySubtractedPSFPhotometry):
                          psf_model=psf_model, fitshape=fitshape,
                          finder=finder, fitter=fitter, niters=niters,
                          aperture_radius=aperture_radius,
-                         extra_output_cols=extra_output_cols)
+                         extra_output_cols=extra_output_cols,
+                         subshape=subshape)
