@@ -5,14 +5,14 @@ for prime-time (i.e., is not considered a stable public API), but is
 included either for experimentation or as legacy code.
 """
 
+import numpy as np
 from astropy.modeling import Fittable2DModel, Parameter
 from astropy.modeling.fitting import LevMarLSQFitter
 from astropy.nddata.utils import extract_array, subpixel_indices
 from astropy.table import Table
 from astropy.utils.decorators import deprecated
-import numpy as np
 
-from ..segmentation.utils import _mask_to_mirrored_value
+from photutils.segmentation.utils import _mask_to_mirrored_value
 
 __all__ = ['DiscretePRF', 'Reproject']
 
@@ -47,7 +47,7 @@ class DiscretePRF(Fittable2DModel):
 
     Parameters
     ----------
-    prf_array : ndarray
+    prf_array : `~numpy.ndarray`
         Array containing PRF images.
     normalize : bool
         Normalize PRF images to unity.  Equivalent to saying there is
