@@ -5,23 +5,23 @@ Tests for the epsf module.
 
 import itertools
 
+import numpy as np
+import pytest
 from astropy.modeling.fitting import LevMarLSQFitter
 from astropy.nddata import NDData
-from astropy.table import Table
 from astropy.stats import SigmaClip
+from astropy.table import Table
 from astropy.utils.exceptions import AstropyUserWarning
-import numpy as np
 from numpy.testing import assert_allclose, assert_almost_equal
-import pytest
 
-from ..epsf import EPSFBuilder, EPSFFitter
-from ..epsf_stars import extract_stars, EPSFStars
-from ..models import IntegratedGaussianPRF, EPSFModel
-from ...datasets import make_gaussian_prf_sources_image
-from ...utils._optional_deps import HAS_SCIPY  # noqa
+from photutils.datasets import make_gaussian_prf_sources_image
+from photutils.psf.epsf import EPSFBuilder, EPSFFitter
+from photutils.psf.epsf_stars import EPSFStars, extract_stars
+from photutils.psf.models import EPSFModel, IntegratedGaussianPRF
+from photutils.utils._optional_deps import HAS_SCIPY
 
 
-@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 class TestEPSFBuild:
     def setup_class(self):
         """
@@ -47,16 +47,16 @@ class TestEPSFBuild:
             if np.min(dist) > min_dist:
                 coords.append(newcoord)
         yy, xx = np.transpose(coords)
-        zz = rng.uniform(low=0, high=200000., size=len(xx))
+        zz = rng.uniform(low=0, high=200000, size=len(xx))
 
         # define a table of model parameters
-        self.stddev = 2.
+        self.stddev = 2.0
         sources = Table()
         sources['amplitude'] = zz
         sources['x_0'] = xx
         sources['y_0'] = yy
         sources['sigma'] = np.zeros(len(xx)) + self.stddev
-        sources['theta'] = 0.
+        sources['theta'] = 0.0
 
         self.data = make_gaussian_prf_sources_image(shape, sources)
         self.nddata = NDData(self.data)
@@ -183,10 +183,11 @@ def test_epsfmodel_inputs():
         EPSFModel(data, origin=origin)
 
 
-@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 @pytest.mark.parametrize('oversamp', [3, 4])
 def test_epsf_build_oversampling(oversamp):
-    offsets = np.arange(oversamp) * 1. / oversamp - 0.5 + 1. / (2. * oversamp)
+    offsets = (np.arange(oversamp) * 1.0 / oversamp - 0.5 + 1.0
+               / (2.0 * oversamp))
     xydithers = np.array(list(itertools.product(offsets, offsets)))
     xdithers = np.transpose(xydithers)[0]
     ydithers = np.transpose(xydithers)[1]
