@@ -3,13 +3,13 @@
 Tests for the groupstars module.
 """
 
-from astropy.table import Table, vstack
 import numpy as np
-from numpy.testing import assert_almost_equal
 import pytest
+from astropy.table import Table, vstack
+from numpy.testing import assert_almost_equal
 
-from ..groupstars import DAOGroup, DBSCANGroup
-from ...utils._optional_deps import HAS_SKLEARN  # noqa
+from photutils.psf.groupstars import DAOGroup, DBSCANGroup
+from photutils.utils._optional_deps import HAS_SKLEARN
 
 
 def assert_table_almost_equal(table1, table2):
@@ -144,8 +144,8 @@ class TestDAOGROUP:
               -1       -0.5        0        0.5        1
         """
 
-        x = np.linspace(-1., 1., 5)
-        y = np.sqrt(1. - x**2)
+        x = np.linspace(-1.0, 1.0, 5)
+        y = np.sqrt(1.0 - x**2)
         xx = np.hstack((x, x))
         yy = np.hstack((y, -y))
         starlist = Table([xx, yy, np.arange(10) + 1,
@@ -273,7 +273,7 @@ class TestDAOGROUP:
             daogroup(starlist['x_0', 'y_0', 'id'])
 
 
-@pytest.mark.skipif('not HAS_SKLEARN')
+@pytest.mark.skipif(not HAS_SKLEARN, reason='sklearn is required')
 class TestDBSCANGroup:
     def test_group_stars_one(self):
         x_0 = np.array([0, np.sqrt(2) / 4, np.sqrt(2) / 4, -np.sqrt(2) / 4,
