@@ -3,33 +3,31 @@
 Tests for the utils module.
 """
 
+import numpy as np
+import pytest
 from astropy.convolution.utils import discretize_model
 from astropy.modeling.models import Gaussian2D
 from astropy.table import Table
-from astropy.utils.exceptions import AstropyDeprecationWarning
-import numpy as np
 from numpy.testing import assert_allclose
-import pytest
-
-from ..groupstars import DAOGroup
-from ..models import IntegratedGaussianPRF
-from ..photometry import BasicPSFPhotometry
-from ..sandbox import DiscretePRF
-from ..utils import get_grouped_psf_model, prepare_psf_model, subtract_psf
-from ...utils._optional_deps import HAS_SCIPY  # noqa
 
+from photutils.psf.groupstars import DAOGroup
+from photutils.psf.models import IntegratedGaussianPRF
+from photutils.psf.photometry import BasicPSFPhotometry
+from photutils.psf.utils import (get_grouped_psf_model, prepare_psf_model,
+                                 subtract_psf)
+from photutils.utils._optional_deps import HAS_SCIPY
 
 PSF_SIZE = 11
-GAUSSIAN_WIDTH = 1.
+GAUSSIAN_WIDTH = 1.0
 IMAGE_SIZE = 101
 
 # Position and FLUXES of test sources
-INTAB = Table([[50., 23, 12, 86], [50., 83, 80, 84],
-               [np.pi * 10, 3.654, 20., 80 / np.sqrt(3)]],
+INTAB = Table([[50.0, 23, 12, 86], [50.0, 83, 80, 84],
+               [np.pi * 10, 3.654, 20.0, 80 / np.sqrt(3)]],
               names=['x_0', 'y_0', 'flux_0'])
 
 # Create test psf
-psf_model = Gaussian2D(1. / (2 * np.pi * GAUSSIAN_WIDTH ** 2), PSF_SIZE // 2,
+psf_model = Gaussian2D(1.0 / (2 * np.pi * GAUSSIAN_WIDTH ** 2), PSF_SIZE // 2,
                        PSF_SIZE // 2, GAUSSIAN_WIDTH, GAUSSIAN_WIDTH)
 test_psf = discretize_model(psf_model, (0, PSF_SIZE), (0, PSF_SIZE),
                             mode='oversample')
@@ -50,8 +48,8 @@ def moffimg():
     """
     This fixture requires scipy so don't call it from non-scipy tests
     """
-    from scipy import integrate
     from astropy.modeling.models import Moffat2D
+    from scipy import integrate
 
     mof = Moffat2D(alpha=4.8)
 
@@ -68,7 +66,7 @@ def moffimg():
     return mof, (xg, yg, mof(xg, yg))
 
 
-@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_moffat_fitting(moffimg):
     """
     Test that the Moffat to be fit in test_psf_adapter is behaving correctly
@@ -85,22 +83,22 @@ def test_moffat_fitting(moffimg):
     f = LevMarLSQFitter()
 
     fit_mof = f(guess_moffat, xg, yg, img)
-    assert_allclose(fit_mof.parameters, mof.parameters, rtol=.01, atol=.0005)
+    assert_allclose(fit_mof.parameters, mof.parameters, rtol=0.01, atol=0.0005)
 
 
 # we set the tolerances in flux to be 2-3% because the shape paraameters of
 # the guessed version are known to be wrong.
 @pytest.mark.parametrize("prepkwargs,tols", [
                          (dict(xname='x_0', yname='y_0', fluxname=None,
-                               renormalize_psf=True), (1e-3, .02)),
+                               renormalize_psf=True), (1e-3, 0.02)),
                          (dict(xname=None, yname=None, fluxname=None,
-                               renormalize_psf=True), (1e-3, .02)),
+                               renormalize_psf=True), (1e-3, 0.02)),
                          (dict(xname=None, yname=None, fluxname=None,
-                               renormalize_psf=False), (1e-3, .03)),
+                               renormalize_psf=False), (1e-3, 0.03)),
                          (dict(xname='x_0', yname='y_0', fluxname='amplitude',
                                renormalize_psf=False), (1e-3, None)),
                          ])
-@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_prepare_psf_model(moffimg, prepkwargs, tols):
     """
     Test that prepare_psf_model behaves as expected for fitting (don't worry
@@ -119,7 +117,7 @@ def test_prepare_psf_model(moffimg, prepkwargs, tols):
     if prepkwargs['renormalize_psf']:
         # definitely very wrong, so this ensures the re-normalization
         # stuff works
-        guess_moffat.amplitude = 5.
+        guess_moffat.amplitude = 5.0
 
     if prepkwargs['xname'] is None:
         guess_moffat.x_0 = 0
@@ -146,15 +144,15 @@ def test_prepare_psf_model(moffimg, prepkwargs, tols):
 
 @pytest.mark.filterwarnings('ignore:aperture_radius is None and could not '
                             'be determined by psf_model')
-@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_prepare_psf_model_offset():
     """
     Regression test to ensure the offset is in the correct direction.
     """
     norm = False
     sigma = 3.0
-    amplitude = 1. / (2 * np.pi * sigma ** 2)
-    xcen = ycen = 0.
+    amplitude = 1.0 / (2 * np.pi * sigma**2)
+    xcen = ycen = 0.0
     psf0 = Gaussian2D(amplitude, xcen, ycen, sigma, sigma)
     psf1 = prepare_psf_model(psf0, xname='x_mean', yname='y_mean',
                              renormalize_psf=norm)
@@ -207,7 +205,7 @@ def test_prepare_psf_model_offset():
                     (xval, yval, flux))
 
 
-@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_get_grouped_psf_model():
     igp = IntegratedGaussianPRF(sigma=1.2)
     tab = Table(names=['x_0', 'y_0', 'flux_0'],
@@ -233,7 +231,7 @@ def prf_model(request):
     return prfs[request.param]
 
 
-@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_get_grouped_psf_model_submodel_names(prf_model):
     """Verify that submodel tagging works"""
     tab = Table(names=['x_0', 'y_0', 'flux_0'],
@@ -248,13 +246,12 @@ def test_get_grouped_psf_model_submodel_names(prf_model):
                 if submodel.name == 1]) == 1
 
 
-@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_subtract_psf():
     """Test subtract_psf."""
-    with pytest.warns(AstropyDeprecationWarning):
-        prf = DiscretePRF(test_psf, subsampling=1)
+    psf = IntegratedGaussianPRF(sigma=1.0)
     posflux = INTAB.copy()
     for n in posflux.colnames:
         posflux.rename_column(n, n.split('_')[0] + '_fit')
-    residuals = subtract_psf(image, prf, posflux)
-    assert_allclose(residuals, np.zeros_like(image), atol=1E-4)
+    residuals = subtract_psf(image, psf, posflux)
+    assert np.max(np.abs(residuals)) < 0.0052
