@@ -4,16 +4,17 @@ This module provides classes for a segmentation image and a single
 segment within a segmentation image.
 """
 
-from copy import deepcopy
 import inspect
 import warnings
+from copy import deepcopy
 
-from astropy.utils import lazyproperty
-from astropy.utils.exceptions import AstropyUserWarning
 import numpy as np
+from astropy.utils import lazyproperty
+from astropy.utils.decorators import deprecated_renamed_argument
+from astropy.utils.exceptions import AstropyUserWarning
 
-from ..aperture import BoundingBox
-from ..utils.colormaps import make_random_cmap
+from photutils.aperture import BoundingBox
+from photutils.utils.colormaps import make_random_cmap
 
 __all__ = ['SegmentationImage', 'Segment']
 
@@ -32,6 +33,14 @@ class SegmentationImage:
         different positive integer values. A value of zero is reserved
         for the background. The segmentation image must have integer
         type.
+
+    Notes
+    -----
+    The `SegmentationImage` instance may be sliced, but note that the
+    sliced `SegmentationImage` data array will be a view into the
+    original `SegmentationImage` array (this is the same behavior as
+    `numpy.ndarray`). Explicitly use the :meth:`SegmentationImage.copy`
+    method to create a copy of the sliced `SegmentationImage`.
     """
 
     def __init__(self, data):
@@ -55,6 +64,18 @@ class SegmentationImage:
     def __repr__(self):
         return self.__str__()
 
+    def __getitem__(self, key):
+        """
+        Slice the segmentation image, returning a new SegmentationImage
+        object.
+        """
+        if (isinstance(key, tuple) and len(key) == 2
+                and all(isinstance(key[i], slice)
+                        and (key[i].start != key[i].stop) for i in (0, 1))):
+            return SegmentationImage(self.data[key])
+        else:
+            raise TypeError(f'{key!r} is not a valid 2D slice object')
+
     def __array__(self):
         """
         Array representation of the segmentation array (e.g., for
@@ -205,6 +226,7 @@ class SegmentationImage:
             If ``label`` is invalid.
         """
         self.check_labels(label)
+        # self.labels is always sorted
         return np.searchsorted(self.labels, label)
 
     def get_indices(self, labels):
@@ -229,6 +251,7 @@ class SegmentationImage:
             If any input ``labels`` are invalid.
         """
         self.check_labels(labels)
+        # self.labels is always sorted
         return np.searchsorted(self.labels, labels)
 
     @lazyproperty
@@ -679,14 +702,12 @@ class SegmentationImage:
         Examples
         --------
         >>> from photutils.segmentation import SegmentationImage
-
         >>> data = np.array([[1, 1, 0, 0, 4, 4],
         ...                  [0, 0, 0, 0, 0, 4],
         ...                  [0, 0, 3, 3, 0, 0],
         ...                  [7, 0, 0, 0, 0, 5],
         ...                  [7, 7, 0, 5, 5, 5],
         ...                  [7, 7, 0, 0, 5, 5]])
-
         >>> segm = SegmentationImage(data)
         >>> segm.keep_label(label=3)
         >>> segm.data
@@ -1042,7 +1063,7 @@ class SegmentationImage:
         Examples
         --------
         >>> import numpy as np
-        >>> from photutils import SegmentationImage
+        >>> from photutils.segmentation import SegmentationImage
         >>> from photutils.utils import circular_footprint
         >>> data = np.zeros((7, 7), dtype=int)
         >>> data[3, 3] = 1
@@ -1062,6 +1083,7 @@ class SegmentationImage:
             return self._data.astype(bool)
 
         from scipy.ndimage import binary_dilation
+
         return binary_dilation(self._data.astype(bool), structure=footprint)
 
     def outline_segments(self, mask_background=False):
@@ -1108,12 +1130,14 @@ class SegmentationImage:
         from scipy.ndimage import (generate_binary_structure, grey_dilation,
                                    grey_erosion)
 
+        # edge connectivity
+        footprint = generate_binary_structure(self._ndim, 1)
+
         # mode='constant' ensures outline is included on the array borders
-        selem = generate_binary_structure(self._ndim, 1)  # edge connectivity
-        eroded = grey_erosion(self.data, footprint=selem, mode='constant',
-                              cval=0.)
-        dilated = grey_dilation(self.data, footprint=selem, mode='constant',
-                                cval=0.)
+        eroded = grey_erosion(self.data, footprint=footprint, mode='constant',
+                              cval=0.0)
+        dilated = grey_dilation(self.data, footprint=footprint,
+                                mode='constant', cval=0.0)
 
         outlines = ((dilated != eroded) & (self.data != 0)).astype(int)
         outlines *= self.data
@@ -1123,7 +1147,8 @@ class SegmentationImage:
 
         return outlines
 
-    def imshow(self, axes=None, figsize=None, dpi=None, cmap=None, alpha=None):
+    @deprecated_renamed_argument('axes', 'ax', '1.6.0')
+    def imshow(self, ax=None, figsize=None, dpi=None, cmap=None, alpha=None):
         """
         Display the segmentation image in a matplotlib
         `~matplotlib.axes.Axes` instance.
@@ -1133,7 +1158,7 @@ class SegmentationImage:
 
         Parameters
         ----------
-        axes : `matplotlib.axes.Axes` or `None`, optional
+        ax : `matplotlib.axes.Axes` or `None`, optional
             The matplotlib axes on which to plot. If `None`, then a new
             `~matplotlib.axes.Axes` instance will be created.
 
@@ -1169,24 +1194,25 @@ class SegmentationImage:
 
             import numpy as np
             from photutils.segmentation import SegmentationImage
+
             data = np.array([[1, 1, 0, 0, 4, 4],
-                            [0, 0, 0, 0, 0, 4],
-                            [0, 0, 3, 3, 0, 0],
-                            [7, 0, 0, 0, 0, 5],
-                            [7, 7, 0, 5, 5, 5],
-                            [7, 7, 0, 0, 5, 5]])
+                             [0, 0, 0, 0, 0, 4],
+                             [0, 0, 3, 3, 0, 0],
+                             [7, 0, 0, 0, 0, 5],
+                             [7, 7, 0, 5, 5, 5],
+                             [7, 7, 0, 0, 5, 5]])
             segm = SegmentationImage(data)
             segm.imshow(figsize=(5, 5))
         """
         import matplotlib.pyplot as plt
 
-        if axes is None:
-            _, axes = plt.subplots(figsize=figsize, dpi=dpi)
+        if ax is None:
+            _, ax = plt.subplots(figsize=figsize, dpi=dpi)
         if cmap is None:
             cmap = self.cmap
 
-        return axes.imshow(self.data, cmap=cmap, interpolation='none',
-                           origin='lower', alpha=alpha)
+        return ax.imshow(self.data, cmap=cmap, interpolation='none',
+                         origin='lower', alpha=alpha)
 
 
 class Segment:
