@@ -4,18 +4,19 @@ This module provides tools for deblending overlapping sources labeled in
 a segmentation image.
 """
 
-from multiprocessing import cpu_count, get_context
 import warnings
+from multiprocessing import cpu_count, get_context
 
+import numpy as np
+from astropy.units import Quantity
 from astropy.utils.decorators import deprecated_renamed_argument
 from astropy.utils.exceptions import AstropyUserWarning
-import numpy as np
 
-from .core import SegmentationImage
-from .detect import _detect_sources
-from .utils import _make_binary_structure
-from ..utils._convolution import _filter_data
-from ..utils._optional_deps import HAS_TQDM  # noqa
+from photutils.segmentation.core import SegmentationImage
+from photutils.segmentation.detect import _detect_sources
+from photutils.segmentation.utils import _make_binary_structure
+from photutils.utils._convolution import _filter_data
+from photutils.utils._optional_deps import HAS_TQDM
 
 __all__ = ['deblend_sources']
 
@@ -144,6 +145,9 @@ def deblend_sources(data, segment_img, npixels, kernel=None, labels=None,
     :func:`photutils.segmentation.detect_sources`
     :class:`photutils.segmentation.SourceFinder`
     """
+    if isinstance(data, Quantity):
+        data = data.value
+
     if not isinstance(segment_img, SegmentationImage):
         raise ValueError('segment_img must be a SegmentationImage')
 
@@ -172,7 +176,7 @@ def deblend_sources(data, segment_img, npixels, kernel=None, labels=None,
             >= (npixels * 2))
     labels = labels[mask]
 
-    selem = _make_binary_structure(data.ndim, connectivity)
+    footprint = _make_binary_structure(data.ndim, connectivity)
 
     if kernel is not None:
         data = _filter_data(data, kernel, mode='constant',
@@ -204,24 +208,26 @@ def deblend_sources(data, segment_img, npixels, kernel=None, labels=None,
 
     if nproc == 1:
         if progress_bar and HAS_TQDM:
-            all_source_data = tqdm(all_source_data)  # pragma: no cover
+            all_source_data = tqdm(all_source_data,
+                                   desc='Deblending')  # pragma: no cover
 
         all_source_deblends = []
         for source_data, source_segment in zip(all_source_data,
                                                all_source_segments):
             deblender = _Deblender(source_data, source_segment, npixels,
-                                   selem, nlevels, contrast, mode)
+                                   footprint, nlevels, contrast, mode)
             source_deblended = deblender.deblend_source()
             all_source_deblends.append(source_deblended)
 
     else:
         nlabels = len(labels)
         args_all = zip(all_source_data, all_source_segments,
-                       (npixels,) * nlabels, (selem,) * nlabels,
+                       (npixels,) * nlabels, (footprint,) * nlabels,
                        (nlevels,) * nlabels, (contrast,) * nlabels,
                        (mode,) * nlabels)
         if progress_bar and HAS_TQDM:
-            args_all = tqdm(args_all, total=nlabels)  # pragma: no cover
+            args_all = tqdm(args_all, total=nlabels,
+                            desc='Deblending')  # pragma: no cover
 
         with get_context('spawn').Pool(processes=nproc) as executor:
             all_source_deblends = executor.starmap(_deblend_source, args_all)
@@ -272,13 +278,13 @@ def deblend_sources(data, segment_img, npixels, kernel=None, labels=None,
     return segm_deblended
 
 
-def _deblend_source(source_data, source_segment, npixels, selem, nlevels,
+def _deblend_source(source_data, source_segment, npixels, footprint, nlevels,
                     contrast, mode):
     """
     Convenience function to deblend a single labeled source with
     multiprocessing.
     """
-    deblender = _Deblender(source_data, source_segment, npixels, selem,
+    deblender = _Deblender(source_data, source_segment, npixels, footprint,
                            nlevels, contrast, mode)
     return deblender.deblend_source()
 
@@ -335,13 +341,13 @@ class _Deblender:
         starting with 1.
     """
 
-    def __init__(self, source_data, source_segment, npixels, selem, nlevels,
-                 contrast, mode):
+    def __init__(self, source_data, source_segment, npixels, footprint,
+                 nlevels, contrast, mode):
 
         self.source_data = source_data
         self.source_segment = source_segment
         self.npixels = npixels
-        self.selem = selem
+        self.footprint = footprint
         self.nlevels = nlevels
         self.contrast = contrast
         self.mode = mode
@@ -398,7 +404,7 @@ class _Deblender:
         with warnings.catch_warnings():
             warnings.simplefilter('ignore', category=RuntimeWarning)
             segments = _detect_sources(self.source_data, thresholds,
-                                       self.npixels, self.selem,
+                                       self.npixels, self.footprint,
                                        self.segment_mask, deblend_mode=True)
         return segments
 
@@ -439,7 +445,8 @@ class _Deblender:
                     markers[mask] = segm_upper[mask].astype(bool)
 
             if relabel:
-                segm_data, nlabels = ndi_label(markers, structure=self.selem)
+                segm_data, nlabels = ndi_label(markers,
+                                               structure=self.footprint)
                 segm_new = object.__new__(SegmentationImage)
                 segm_new._data = segm_data
                 segm_new.__dict__['labels'] = np.arange(nlabels) + 1
@@ -479,7 +486,7 @@ class _Deblender:
         while remove_marker:
             markers = watershed(-self.source_data, markers,
                                 mask=self.segment_mask,
-                                connectivity=self.selem)
+                                connectivity=self.footprint)
 
             labels = np.unique(markers[markers != 0])
             flux_frac = (sum_labels(self.source_data, markers, index=labels)
@@ -490,7 +497,7 @@ class _Deblender:
                 # remove only the faintest source (one at a time) because
                 # several faint sources could combine to meet the contrast
                 # criterion
-                markers[markers == labels[np.argmin(flux_frac)]] = 0.
+                markers[markers == labels[np.argmin(flux_frac)]] = 0.0
 
         return markers
 
