@@ -2,53 +2,55 @@
 """
 Tests for the catalog module.
 """
+
+import astropy.units as u
+import numpy as np
+import pytest
 from astropy.convolution import convolve
 from astropy.coordinates import SkyCoord
 from astropy.modeling.models import Gaussian2D
 from astropy.table import QTable
-import astropy.units as u
-from numpy.testing import assert_allclose, assert_equal, assert_raises
-import numpy as np
-import pytest
+from numpy.testing import assert_allclose, assert_equal
 
-from ..catalog import SourceCatalog
-from ..core import SegmentationImage
-from ..detect import detect_sources
-from ..finder import SourceFinder
-from ..utils import make_2dgaussian_kernel
-from ...aperture import CircularAperture, EllipticalAperture
-from ...background import Background2D, MedianBackground
-from ...datasets import (make_gwcs, make_wcs, make_noise_image,
-                         make_100gaussians_image)
-from ...utils._convolution import _filter_data
-from ...utils.cutouts import CutoutImage
-from ...utils._optional_deps import HAS_GWCS, HAS_MATPLOTLIB, HAS_SCIPY  # noqa
+from photutils.aperture import (BoundingBox, CircularAperture,
+                                EllipticalAperture)
+from photutils.background import Background2D, MedianBackground
+from photutils.datasets import (make_100gaussians_image, make_gwcs,
+                                make_noise_image, make_wcs)
+from photutils.segmentation.catalog import SourceCatalog
+from photutils.segmentation.core import SegmentationImage
+from photutils.segmentation.detect import detect_sources
+from photutils.segmentation.finder import SourceFinder
+from photutils.segmentation.utils import make_2dgaussian_kernel
+from photutils.utils._convolution import _filter_data
+from photutils.utils._optional_deps import HAS_GWCS, HAS_MATPLOTLIB, HAS_SCIPY
+from photutils.utils.cutouts import CutoutImage
 
 
-@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 class TestSourceCatalog:
     def setup_class(self):
-        xcen = 51.
+        xcen = 51.0
         ycen = 52.7
-        major_sigma = 8.
-        minor_sigma = 3.
-        theta = np.pi / 6.
-        g1 = Gaussian2D(111., xcen, ycen, major_sigma, minor_sigma,
+        major_sigma = 8.0
+        minor_sigma = 3.0
+        theta = np.pi / 6.0
+        g1 = Gaussian2D(111.0, xcen, ycen, major_sigma, minor_sigma,
                         theta=theta)
         g2 = Gaussian2D(50, 20, 80, 5.1, 4.5)
         g3 = Gaussian2D(70, 75, 18, 9.2, 4.5)
-        g4 = Gaussian2D(111., 11.1, 12.2, major_sigma, minor_sigma,
+        g4 = Gaussian2D(111.0, 11.1, 12.2, major_sigma, minor_sigma,
                         theta=theta)
-        g5 = Gaussian2D(81., 61, 42.7, major_sigma, minor_sigma, theta=theta)
-        g6 = Gaussian2D(107., 75, 61, major_sigma, minor_sigma, theta=-theta)
-        g7 = Gaussian2D(107., 90, 90, 4, 2, theta=-theta)
+        g5 = Gaussian2D(81.0, 61, 42.7, major_sigma, minor_sigma, theta=theta)
+        g6 = Gaussian2D(107.0, 75, 61, major_sigma, minor_sigma, theta=-theta)
+        g7 = Gaussian2D(107.0, 90, 90, 4, 2, theta=-theta)
 
         yy, xx = np.mgrid[0:101, 0:101]
         self.data = (g1(xx, yy) + g2(xx, yy) + g3(xx, yy) + g4(xx, yy)
                      + g5(xx, yy) + g6(xx, yy) + g7(xx, yy))
-        threshold = 27.
+        threshold = 27.0
         self.segm = detect_sources(self.data, threshold, npixels=5)
-        self.error = make_noise_image(self.data.shape, mean=0, stddev=2.,
+        self.error = make_noise_image(self.data.shape, mean=0, stddev=2.0,
                                       seed=123)
         self.background = np.ones(self.data.shape) * 5.1
         self.mask = np.zeros(self.data.shape, dtype=bool)
@@ -68,25 +70,6 @@ class TestSourceCatalog:
 
     @pytest.mark.parametrize('with_units', (True, False))
     def test_catalog(self, with_units):
-        props1 = ('background_centroid', 'background_mean', 'background_sum',
-                  'bbox', 'covar_sigx2', 'covar_sigxy', 'covar_sigy2', 'cxx',
-                  'cxy', 'cyy', 'ellipticity', 'elongation', 'fwhm',
-                  'equivalent_radius', 'gini', 'kron_radius', 'maxval_xindex',
-                  'maxval_yindex', 'minval_xindex', 'minval_yindex',
-                  'perimeter', 'sky_bbox_ll', 'sky_bbox_lr', 'sky_bbox_ul',
-                  'sky_bbox_ur', 'sky_centroid_icrs', 'local_background',
-                  'segment_flux', 'segment_fluxerr', 'kron_flux',
-                  'kron_fluxerr')
-
-        props2 = ('centroid', 'covariance', 'covariance_eigvals',
-                  'cutout_centroid', 'cutout_maxval_index',
-                  'cutout_minval_index', 'inertia_tensor', 'maxval_index',
-                  'minval_index', 'moments', 'moments_central', 'background',
-                  'background_ma', 'convdata', 'convdata_ma', 'data',
-                  'data_ma', 'error', 'error_ma', 'segment', 'segment_ma')
-
-        props = tuple(self.cat.default_columns) + props1 + props2
-
         if with_units:
             cat1 = self.cat_units.copy()
             cat2 = self.cat_units.copy()
@@ -94,16 +77,18 @@ class TestSourceCatalog:
             cat1 = self.cat.copy()
             cat2 = self.cat.copy()
 
-        # test extra properties
+        props = self.cat.properties
+
+        # add extra properties
         cat1.circular_photometry(5.0, name='circ5')
-        cat1.kron_photometry((2.0, 1.0), name='kron2')
+        cat1.kron_photometry((2.5, 1.4), name='kron2')
         cat1.fluxfrac_radius(0.5, name='r_hl')
         segment_snr = cat1.segment_flux / cat1.segment_fluxerr
         cat1.add_extra_property('segment_snr', segment_snr)
         props = list(props)
         props.extend(cat1.extra_properties)
 
-        idx = 1
+        idx = 1  # no NaN values
 
         # evaluate (cache) catalog properties before slice
         obj = cat1[idx]
@@ -113,13 +98,17 @@ class TestSourceCatalog:
         # slice catalog before evaluating catalog properties
         obj = cat2[idx]
         obj.circular_photometry(5.0, name='circ5')
-        obj.kron_photometry((2.0, 1.0), name='kron2')
+        obj.kron_photometry((2.5, 1.4), name='kron2')
         obj.fluxfrac_radius(0.5, name='r_hl')
         segment_snr = obj.segment_flux / obj.segment_fluxerr
         obj.add_extra_property('segment_snr', segment_snr)
         for prop in props:
             assert_equal(getattr(obj, prop), getattr(cat1, prop)[idx])
 
+        with pytest.raises(ValueError):
+            cat1._prepare_cutouts(cat1._segment_img_cutouts, units=True,
+                                  masked=True)
+
     @pytest.mark.parametrize('with_units', (True, False))
     def test_catalog_detection_cat(self, with_units):
         """
@@ -153,48 +142,48 @@ class TestSourceCatalog:
 
         assert_equal(cat1.kron_radius, cat3.kron_radius)
         # assert not equal
-        with assert_raises(AssertionError):
+        with pytest.raises(AssertionError):
             assert_equal(cat1.kron_radius, cat2.kron_radius)
 
-        with assert_raises(AssertionError):
+        with pytest.raises(AssertionError):
             assert_equal(cat2.kron_flux, cat3.kron_flux)
-        with assert_raises(AssertionError):
+        with pytest.raises(AssertionError):
             assert_equal(cat2.kron_fluxerr, cat3.kron_fluxerr)
-        with assert_raises(AssertionError):
+        with pytest.raises(AssertionError):
             assert_equal(cat1.kron_flux, cat3.kron_flux)
-        with assert_raises(AssertionError):
+        with pytest.raises(AssertionError):
             assert_equal(cat1.kron_fluxerr, cat3.kron_fluxerr)
 
         flux1, fluxerr1 = cat1.circular_photometry(1.0)
         flux2, fluxerr2 = cat2.circular_photometry(1.0)
         flux3, fluxerr3 = cat3.circular_photometry(1.0)
-        with assert_raises(AssertionError):
+        with pytest.raises(AssertionError):
             assert_equal(flux2, flux3)
-        with assert_raises(AssertionError):
+        with pytest.raises(AssertionError):
             assert_equal(fluxerr2, fluxerr3)
-        with assert_raises(AssertionError):
+        with pytest.raises(AssertionError):
             assert_equal(flux1, flux2)
-        with assert_raises(AssertionError):
+        with pytest.raises(AssertionError):
             assert_equal(fluxerr1, fluxerr2)
 
-        flux1, fluxerr1 = cat1.kron_photometry((2.0, 1.0))
-        flux2, fluxerr2 = cat2.kron_photometry((2.0, 1.0))
-        flux3, fluxerr3 = cat3.kron_photometry((2.0, 1.0))
-        with assert_raises(AssertionError):
+        flux1, fluxerr1 = cat1.kron_photometry((2.5, 1.4))
+        flux2, fluxerr2 = cat2.kron_photometry((2.5, 1.4))
+        flux3, fluxerr3 = cat3.kron_photometry((2.5, 1.4))
+        with pytest.raises(AssertionError):
             assert_equal(flux2, flux3)
-        with assert_raises(AssertionError):
+        with pytest.raises(AssertionError):
             assert_equal(fluxerr2, fluxerr3)
-        with assert_raises(AssertionError):
+        with pytest.raises(AssertionError):
             assert_equal(flux1, flux2)
-        with assert_raises(AssertionError):
+        with pytest.raises(AssertionError):
             assert_equal(fluxerr1, fluxerr2)
 
         radius1 = cat1.fluxfrac_radius(0.5)
         radius2 = cat2.fluxfrac_radius(0.5)
         radius3 = cat3.fluxfrac_radius(0.5)
-        with assert_raises(AssertionError):
+        with pytest.raises(AssertionError):
             assert_equal(radius2, radius3)
-        with assert_raises(AssertionError):
+        with pytest.raises(AssertionError):
             assert_equal(radius1, radius2)
 
         cat4 = cat3[0:1]
@@ -217,7 +206,7 @@ class TestSourceCatalog:
             assert np.isnan(getattr(obj, prop))
 
         assert obj.local_background_aperture is None
-        assert obj.local_background == 0.
+        assert obj.local_background == 0.0
 
     def test_slicing(self):
         self.cat.to_table()  # evaluate and cache several properties
@@ -249,6 +238,12 @@ class TestSourceCatalog:
         assert len(obj5) == 3
         assert_equal(obj5.label, labels)
 
+        # test get_labels when labels are not sorted
+        obj5 = self.cat[[3, 2, 1]]
+        labels2 = (3, 4)
+        obj5b = obj5.get_labels(labels2)
+        assert_equal(obj5b.label, labels2)
+
         obj6 = obj5[0]
         assert obj6.label == labels[0]
 
@@ -358,18 +353,20 @@ class TestSourceCatalog:
         obj = cat[0]
         assert obj.sky_centroid is not None
         assert obj.sky_centroid_icrs is not None
+        assert obj.sky_centroid_win is not None
         assert obj.sky_bbox_ll is not None
         assert obj.sky_bbox_ul is not None
         assert obj.sky_bbox_lr is not None
         assert obj.sky_bbox_ur is not None
 
-    @pytest.mark.skipif('not HAS_GWCS')
+    @pytest.mark.skipif(not HAS_GWCS, reason='gwcs is required')
     def test_gwcs(self):
         mywcs = make_gwcs(self.data.shape)
         cat = SourceCatalog(self.data, self.segm, wcs=mywcs)
         obj = cat[1]
         assert obj.sky_centroid is not None
         assert obj.sky_centroid_icrs is not None
+        assert obj.sky_centroid_win is not None
         assert obj.sky_bbox_ll is not None
         assert obj.sky_bbox_ul is not None
         assert obj.sky_bbox_lr is not None
@@ -380,6 +377,7 @@ class TestSourceCatalog:
         obj = cat[2]
         assert obj.sky_centroid is None
         assert obj.sky_centroid_icrs is None
+        assert obj.sky_centroid_win is None
         assert obj.sky_bbox_ll is None
         assert obj.sky_bbox_ul is None
         assert obj.sky_bbox_lr is None
@@ -438,7 +436,7 @@ class TestSourceCatalog:
             assert line in repr(cat)
 
     def test_kernel(self):
-        kernel = np.array([[1., 2, 1], [2, 4, 2], [1, 2, 100]])
+        kernel = np.array([[1.0, 2, 1], [2, 4, 2], [1, 2, 100]])
         kernel /= kernel.sum()
 
         cat1 = SourceCatalog(self.data, self.segm, kernel=None)
@@ -502,15 +500,15 @@ class TestSourceCatalog:
 
     def test_kron_negative(self):
         cat = SourceCatalog(self.data - 10, self.segm)
-        assert_allclose(cat.kron_radius.value, cat._kron_params[1])
+        assert_allclose(cat.kron_radius.value, cat.kron_params[1])
 
     def test_kron_photometry(self):
-        flux1, fluxerr1 = self.cat.kron_photometry((2.5, 1.0))
-        assert_allclose(flux1, self.cat.kron_flux)
-        assert_allclose(fluxerr1, self.cat.kron_fluxerr)
+        flux0, fluxerr0 = self.cat.kron_photometry((2.5, 1.4))
+        assert_allclose(flux0, self.cat.kron_flux)
+        assert_allclose(fluxerr0, self.cat.kron_fluxerr)
 
-        flux1, fluxerr1 = self.cat.kron_photometry((1.0, 1.0), name='kron1')
-        flux2, fluxerr2 = self.cat.kron_photometry((2.0, 1.0), name='kron2')
+        flux1, fluxerr1 = self.cat.kron_photometry((1.0, 1.4), name='kron1')
+        flux2, fluxerr2 = self.cat.kron_photometry((2.0, 1.4), name='kron2')
         assert_allclose(flux1, self.cat.kron1_flux)
         assert_allclose(fluxerr1, self.cat.kron1_fluxerr)
         assert_allclose(flux2, self.cat.kron2_flux)
@@ -520,25 +518,31 @@ class TestSourceCatalog:
         assert np.all((fluxerr2 > fluxerr1)
                       | (np.isnan(fluxerr2) & np.isnan(fluxerr1)))
 
+        # test different min Kron radius
+        flux3, fluxerr3 = self.cat.kron_photometry((2.5, 2.5))
+        assert np.all((flux3 > flux0) | (np.isnan(flux3) & np.isnan(flux0)))
+        assert np.all((fluxerr3 > fluxerr0)
+                      | (np.isnan(fluxerr3) & np.isnan(fluxerr0)))
+
         obj = self.cat[1]
-        flux1, fluxerr1 = obj.kron_photometry((1.0, 1.0), name='kron0')
+        flux1, fluxerr1 = obj.kron_photometry((1.0, 1.4), name='kron0')
         assert np.isscalar(flux1)
         assert np.isscalar(fluxerr1)
         assert_allclose(flux1, obj.kron0_flux)
         assert_allclose(fluxerr1, obj.kron0_fluxerr)
 
         cat = SourceCatalog(self.data, self.segm)
-        _, fluxerr = cat.kron_photometry((2.0, 1.0))
+        _, fluxerr = cat.kron_photometry((2.0, 1.4))
         assert np.all(np.isnan(fluxerr))
 
         with pytest.raises(ValueError):
-            self.cat.kron_photometry(2.0)
+            self.cat.kron_photometry(2.5)
         with pytest.raises(ValueError):
-            self.cat.kron_photometry((2.0, 0.0))
+            self.cat.kron_photometry((2.5, 0.0))
         with pytest.raises(ValueError):
-            self.cat.kron_photometry((0.0, 2.0))
+            self.cat.kron_photometry((0.0, 1.4))
         with pytest.raises(ValueError):
-            self.cat.kron_photometry((2.0, 0.0, 1.5))
+            self.cat.kron_photometry((2.5, 0.0, 1.5))
 
     def test_circular_photometry(self):
         flux1, fluxerr1 = self.cat.circular_photometry(1.0, name='circ1')
@@ -564,6 +568,14 @@ class TestSourceCatalog:
         _, fluxerr = cat.circular_photometry(1.0)
         assert np.all(np.isnan(fluxerr))
 
+        # with "center" mode, tiny apertures that do not overlap any
+        # center should return NaN
+        cat2 = self.cat.copy()
+        cat2._set_semode()  # sets "center" mode
+        flux1, fluxerr1 = cat2.circular_photometry(0.1)
+        assert np.all(np.isnan(flux1[2:4]))
+        assert np.all(np.isnan(fluxerr1[2:4]))
+
         with pytest.raises(ValueError):
             self.cat.circular_photometry(0.0)
         with pytest.raises(ValueError):
@@ -573,7 +585,7 @@ class TestSourceCatalog:
         with pytest.raises(ValueError):
             self.cat.make_circular_apertures(-1.0)
 
-    @pytest.mark.skipif('not HAS_MATPLOTLIB')
+    @pytest.mark.skipif(not HAS_MATPLOTLIB, reason='matplotlib is required')
     def test_plots(self):
         from matplotlib.patches import Patch
 
@@ -587,11 +599,18 @@ class TestSourceCatalog:
         for patch in patches:
             assert isinstance(patch, Patch)
 
-        patches2 = self.cat.plot_kron_apertures((2.5, 1.0))
+        patches2 = self.cat.plot_kron_apertures((2.0, 1.2))
         assert isinstance(patches2, list)
         for patch in patches2:
             assert isinstance(patch, Patch)
 
+        # test scalar
+        obj = self.cat[1]
+        patch1 = obj.plot_kron_apertures()
+        assert isinstance(patch1, Patch)
+        patch2 = obj.plot_kron_apertures((2.0, 1.2))
+        assert isinstance(patch2, Patch)
+
     def test_fluxfrac_radius(self):
         radius1 = self.cat.fluxfrac_radius(0.1, name='fluxfrac_r1')
         radius2 = self.cat.fluxfrac_radius(0.5, name='fluxfrac_r5')
@@ -611,7 +630,7 @@ class TestSourceCatalog:
         with pytest.raises(ValueError):
             radius = self.cat.fluxfrac_radius(-1)
 
-        cat = SourceCatalog(self.data - 50., self.segm, error=self.error,
+        cat = SourceCatalog(self.data - 50.0, self.segm, error=self.error,
                             background=self.background, mask=self.mask,
                             wcs=self.wcs, localbkg_width=24)
         radius_hl = cat.fluxfrac_radius(0.5)
@@ -681,6 +700,9 @@ class TestSourceCatalog:
             cat.add_extra_property('invalid', segment_snr)
         cat._extra_properties.remove('invalid')
 
+        assert cat._has_len([1, 2, 3])
+        assert not cat._has_len('test_string')
+
     def test_extra_properties_invalid(self):
         cat = SourceCatalog(self.data, self.segm)
         with pytest.raises(ValueError):
@@ -744,7 +766,7 @@ class TestSourceCatalog:
         assert len(aper) == len(self.cat)
         assert isinstance(aper[1], EllipticalAperture)
 
-        aper2 = self.cat.make_kron_apertures((2.5, 1))
+        aper2 = self.cat.make_kron_apertures((2.0, 1.4))
         assert len(aper2) == len(self.cat)
 
         obj = self.cat[1]
@@ -752,19 +774,64 @@ class TestSourceCatalog:
         assert isinstance(aper, EllipticalAperture)
 
     def test_make_cutouts(self):
-        shape = (10, 11)
-        cut = self.cat.make_cutouts(shape)
-        assert len(cut) == len(self.cat)
-        assert isinstance(cut[1], CutoutImage)
-        assert cut[1].data.shape == shape
+        data = make_100gaussians_image()
+        bkg_estimator = MedianBackground()
+        bkg = Background2D(data, (50, 50), filter_size=(3, 3),
+                           bkg_estimator=bkg_estimator)
+        data -= bkg.background  # subtract the background
+        threshold = 1.5 * bkg.background_rms
+        kernel = make_2dgaussian_kernel(3.0, size=5)
+        convolved_data = convolve(data, kernel)
+        npixels = 10
+        finder = SourceFinder(npixels=npixels, progress_bar=False)
+        segment_map = finder(convolved_data, threshold)
+        cat = SourceCatalog(data, segment_map, convolved_data=convolved_data)
 
-        obj = self.cat[1]
+        shape = (100, 100)
+
+        with pytest.raises(ValueError):
+            cat.make_cutouts(shape, mode='strict')
+
+        cutouts = cat.make_cutouts(shape, mode='trim')
+        assert cutouts[0].data.shape != shape
+        assert_equal(cutouts[0].xyorigin, np.array((186, 0)))
+        assert (cutouts[0].bbox_original
+                == BoundingBox(ixmin=186, ixmax=286, iymin=0, iymax=52))
+
+        cutouts = cat.make_cutouts(shape, mode='partial')
+        assert_equal(cutouts[0].xyorigin, np.array((186, -48)))
+        assert (cutouts[0].bbox_original
+                == BoundingBox(ixmin=186, ixmax=286, iymin=0, iymax=52))
+
+        assert len(cutouts) == len(cat)
+        assert isinstance(cutouts[1], CutoutImage)
+        assert cutouts[1].data.shape == shape
+
+        obj = cat[1]
         cut = obj.make_cutouts(shape)
         assert isinstance(cut, CutoutImage)
         assert cut.data.shape == shape
 
+        cutouts = cat.make_cutouts(shape, mode='partial', fill_value=-100)
+        assert cutouts[0].data[0, 0] == -100
 
-@pytest.mark.skipif('not HAS_SCIPY')
+        # cutout will be None if source is completely masked
+        cutouts = self.cat.make_cutouts(shape)
+        assert cutouts[0] is None
+
+    def test_meta(self):
+        meta = self.cat.meta
+        attrs = ('localbkg_width', 'apermask_method', 'kron_params')
+        for attr in attrs:
+            assert attr in meta
+
+    def test_semode(self):
+        self.cat._set_semode()
+        tbl = self.cat.to_table()
+        assert len(tbl) == 7
+
+
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_kron_params():
     data = make_100gaussians_image()
     bkg_estimator = MedianBackground()
@@ -816,3 +883,51 @@ def test_kron_params():
     rh = cat.fluxfrac_radius(0.5)
     assert_allclose(rh.value.min(), 1.3649418211298536)
     assert isinstance(cat.kron_aperture[0], CircularAperture)
+
+
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
+def test_centroid_win():
+    g1 = Gaussian2D(1621, 6.29, 10.95, 1.55, 1.29, 0.296706)
+    g2 = Gaussian2D(3596, 13.81, 8.29, 1.44, 1.27, 0.628319)
+    m = g1 + g2
+    yy, xx = np.mgrid[0:21, 0:21]
+    data = m(xx, yy)
+    noise = make_noise_image(data.shape, mean=0, stddev=65.0, seed=123)
+    data += noise
+
+    kernel = make_2dgaussian_kernel(3.0, size=5)
+    convolved_data = convolve(data, kernel)
+    npixels = 10
+    finder = SourceFinder(npixels=npixels, progress_bar=False)
+    threshold = 107.9
+    segment_map = finder(convolved_data, threshold)
+    cat = SourceCatalog(data, segment_map, convolved_data=convolved_data,
+                        apermask_method='none')
+
+    assert cat.xcentroid[0] != cat.xcentroid_win[0]
+    assert cat.ycentroid[0] != cat.ycentroid_win[0]
+    # centroid_win moved beyond 1-sigma ellipse and was reset to
+    # isophotal centroid
+    assert cat.xcentroid[1] == cat.xcentroid_win[1]
+    assert cat.ycentroid[1] == cat.ycentroid_win[1]
+
+
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
+def test_centroid_win_migrate():
+    """
+    Test that when the windowed centroid moves the aperture completely
+    off the image the isophotal centroid is returned.
+    """
+    g1 = Gaussian2D(1621, 76.29, 185.95, 1.55, 1.29, 0.296706)
+    g2 = Gaussian2D(3596, 83.81, 182.29, 1.44, 1.27, 0.628319)
+    m = g1 + g2
+    yy, xx = np.mgrid[0:256, 0:256]
+    data = m(xx, yy)
+    noise = make_noise_image(data.shape, mean=0, stddev=65.0, seed=123)
+    data += noise
+    segm = detect_sources(data, 98.0, npixels=5)
+    cat = SourceCatalog(data, segm)
+
+    indices = (0, 3, 14, 30)
+    for idx in indices:
+        assert_equal(cat.centroid_win[idx], cat.centroid[idx])
