@@ -3,18 +3,18 @@
 Tests for the core module.
 """
 
+import numpy as np
+import pytest
 from astropy.utils import lazyproperty
 from astropy.utils.exceptions import AstropyUserWarning
-import numpy as np
 from numpy.testing import assert_allclose, assert_equal
-import pytest
 
-from ..core import Segment, SegmentationImage
-from ...utils import circular_footprint
-from ...utils._optional_deps import HAS_MATPLOTLIB, HAS_SCIPY  # noqa
+from photutils.segmentation.core import Segment, SegmentationImage
+from photutils.utils import circular_footprint
+from photutils.utils._optional_deps import HAS_MATPLOTLIB, HAS_SCIPY
 
 
-@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 class TestSegmentationImage:
     def setup_class(self):
         self.data = np.array([[1, 1, 0, 0, 4, 4],
@@ -33,9 +33,22 @@ class TestSegmentationImage:
         segm2 = segm.copy()
         assert segm.data is not segm2.data
         assert segm.labels is not segm2.labels
-        segm.data[0, 0] = 100.
+        segm.data[0, 0] = 100.0
         assert segm.data[0, 0] != segm2.data[0, 0]
 
+    def test_slicing(self):
+        segm2 = self.segm[1:5, 2:5]
+        assert segm2.shape == (4, 3)
+        assert_equal(segm2.labels, [3, 5])
+        assert segm2.data.sum() == 16
+
+        with pytest.raises(TypeError):
+            self.segm[1]
+        with pytest.raises(TypeError):
+            self.segm[1:10]
+        with pytest.raises(TypeError):
+            self.segm[1:1, 2:4]
+
     def test_data_all_zeros(self):
         data = np.zeros((5, 5), dtype=int)
         segm = SegmentationImage(data)
@@ -91,7 +104,7 @@ class TestSegmentationImage:
 
         assert (self.segm.segments[0].data_ma.shape
                 == self.segm.segments[0].data.shape)
-        assert (self.segm.segments[0].data_ma.filled(0.).sum()
+        assert (self.segm.segments[0].data_ma.filled(0.0).sum()
                 == self.segm.segments[0].data.sum())
 
         label = 4
@@ -179,7 +192,7 @@ class TestSegmentationImage:
         with pytest.raises(ValueError):
             _ = segm.bbox
 
-    @pytest.mark.skipif('not HAS_MATPLOTLIB')
+    @pytest.mark.skipif(not HAS_MATPLOTLIB, reason='matplotlib is required')
     def test_make_cmap(self):
         cmap = self.segm.make_cmap()
         assert len(cmap.colors) == (self.segm.max_label + 1)
@@ -189,12 +202,12 @@ class TestSegmentationImage:
                         self.segm.make_cmap(background_color='#000000ff',
                                             seed=0).colors)
 
-    @pytest.mark.skipif('not HAS_MATPLOTLIB')
-    @pytest.mark.parametrize('color, alpha', (('#00000000', 0.),
+    @pytest.mark.skipif(not HAS_MATPLOTLIB, reason='matplotlib is required')
+    @pytest.mark.parametrize('color, alpha', (('#00000000', 0.0),
                                               ('#00000040', 64 / 255),
                                               ('#00000080', 128 / 255),
                                               ('#000000C0', 192 / 255),
-                                              ('#000000FF', 1.)))
+                                              ('#000000FF', 1.0)))
     def test_make_cmap_alpha(self, color, alpha):
         cmap = self.segm.make_cmap(background_color=color)
         assert_allclose(cmap.colors[0], (0, 0, 0, alpha))
@@ -229,6 +242,12 @@ class TestSegmentationImage:
         assert_allclose(segm.data, ref_data)
         assert segm.nlabels == len(segm.slices) - segm.slices.count(None)
 
+        # test slices caching
+        segm = SegmentationImage(self.data.copy())
+        slc1 = segm.slices
+        segm.relabel_consecutive()
+        assert slc1 == segm.slices
+
     @pytest.mark.parametrize('start_label', [0, -1])
     def test_relabel_consecutive_start_invalid(self, start_label):
         with pytest.raises(ValueError):
@@ -371,10 +390,11 @@ class TestSegmentationImage:
         assert np.ma.count(segm_outlines) == 8
         assert np.ma.count_masked(segm_outlines) == 17
 
-    @pytest.mark.skipif('not HAS_MATPLOTLIB')
+    @pytest.mark.skipif(not HAS_MATPLOTLIB, reason='matplotlib is required')
     def test_imshow(self):
-        axim = self.segm.imshow(figsize=(5, 5))
         from matplotlib.image import AxesImage
+
+        axim = self.segm.imshow(figsize=(5, 5))
         assert isinstance(axim, AxesImage)
 
 
@@ -384,7 +404,7 @@ class CustomSegm(SegmentationImage):
         return np.median(self.data)
 
 
-@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_subclass():
     """
     Test that cached properties are reset in SegmentationImage
