@@ -3,25 +3,25 @@
 Tests for the detect module.
 """
 
-from astropy.convolution import Gaussian2DKernel
-from astropy.stats import gaussian_fwhm_to_sigma, SigmaClip
-from astropy.utils.exceptions import AstropyDeprecationWarning
+import astropy.units as u
 import numpy as np
-from numpy.testing import assert_allclose, assert_array_equal
 import pytest
+from astropy.stats import SigmaClip
+from astropy.utils.exceptions import AstropyDeprecationWarning
+from numpy.testing import assert_allclose, assert_array_equal
 
-from ..detect import detect_threshold, detect_sources, make_source_mask
-from ..utils import make_2dgaussian_kernel
-from ...datasets import make_4gaussians_image
-from ...utils.exceptions import NoDetectionsWarning
-from ...utils._optional_deps import HAS_SCIPY  # noqa
-
+from photutils.datasets import make_4gaussians_image
+from photutils.segmentation.detect import (detect_sources, detect_threshold,
+                                           make_source_mask)
+from photutils.segmentation.utils import make_2dgaussian_kernel
+from photutils.utils._optional_deps import HAS_SCIPY
+from photutils.utils.exceptions import NoDetectionsWarning
 
 DATA = np.array([[0, 1, 0], [0, 2, 0], [0, 0, 0]]).astype(float)
 REF1 = np.array([[0, 0, 0], [0, 1, 0], [0, 0, 0]])
 
 
-@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 class TestDetectThreshold:
     def test_nsigma(self):
         """Test basic nsigma."""
@@ -29,65 +29,85 @@ class TestDetectThreshold:
         ref = 0.4 * np.ones((3, 3))
         assert_allclose(threshold, ref)
 
+        threshold = detect_threshold(DATA << u.uJy, nsigma=0.1)
+        assert isinstance(threshold, u.Quantity)
+        assert_allclose(threshold.value, ref)
+
     def test_nsigma_zero(self):
         """Test nsigma=0."""
         threshold = detect_threshold(DATA, nsigma=0.0)
-        ref = (1. / 3.) * np.ones((3, 3))
+        ref = (1.0 / 3.0) * np.ones((3, 3))
         assert_allclose(threshold, ref)
 
     def test_background(self):
         threshold = detect_threshold(DATA, nsigma=1.0, background=1)
-        ref = (5. / 3.) * np.ones((3, 3))
+        ref = (5.0 / 3.0) * np.ones((3, 3))
         assert_allclose(threshold, ref)
 
     def test_background_image(self):
         background = np.ones((3, 3))
         threshold = detect_threshold(DATA, nsigma=1.0, background=background)
-        ref = (5. / 3.) * np.ones((3, 3))
+        ref = (5.0 / 3.0) * np.ones((3, 3))
         assert_allclose(threshold, ref)
 
+        threshold = detect_threshold(DATA << u.Jy, nsigma=1.0,
+                                     background=background << u.Jy)
+        assert isinstance(threshold, u.Quantity)
+        assert_allclose(threshold.value, ref)
+
     def test_background_badshape(self):
         wrong_shape = np.zeros((2, 2))
         with pytest.raises(ValueError):
-            detect_threshold(DATA, nsigma=2., background=wrong_shape)
+            detect_threshold(DATA, nsigma=2.0, background=wrong_shape)
 
     def test_error(self):
         threshold = detect_threshold(DATA, nsigma=1.0, error=1)
-        ref = (4. / 3.) * np.ones((3, 3))
+        ref = (4.0 / 3.0) * np.ones((3, 3))
         assert_allclose(threshold, ref)
 
     def test_error_image(self):
         error = np.ones((3, 3))
         threshold = detect_threshold(DATA, nsigma=1.0, error=error)
-        ref = (4. / 3.) * np.ones((3, 3))
+        ref = (4.0 / 3.0) * np.ones((3, 3))
         assert_allclose(threshold, ref)
 
+        threshold = detect_threshold(DATA << u.Jy, nsigma=1.0,
+                                     error=error << u.Jy)
+        assert isinstance(threshold, u.Quantity)
+        assert_allclose(threshold.value, ref)
+
     def test_error_badshape(self):
         wrong_shape = np.zeros((2, 2))
         with pytest.raises(ValueError):
-            detect_threshold(DATA, nsigma=2., error=wrong_shape)
+            detect_threshold(DATA, nsigma=2.0, error=wrong_shape)
 
     def test_background_error(self):
-        threshold = detect_threshold(DATA, nsigma=2.0, background=10.,
-                                     error=1.)
-        ref = 12. * np.ones((3, 3))
+        threshold = detect_threshold(DATA, nsigma=2.0, background=10.0,
+                                     error=1.0)
+        ref = 12.0 * np.ones((3, 3))
         assert_allclose(threshold, ref)
 
+        threshold = detect_threshold(DATA << u.Jy, nsigma=2.0,
+                                     background=10.0 * u.Jy,
+                                     error=1.0 * u.Jy)
+        assert isinstance(threshold, u.Quantity)
+        assert_allclose(threshold.value, ref)
+
+        with pytest.raises(ValueError):
+            detect_threshold(DATA << u.Jy, nsigma=2.0, background=10.0,
+                             error=1.0 * u.Jy)
+        with pytest.raises(ValueError):
+            detect_threshold(DATA << u.Jy, nsigma=2.0, background=10.0 * u.m,
+                             error=1.0 * u.Jy)
+
     def test_background_error_images(self):
-        background = np.ones((3, 3)) * 10.
+        background = np.ones((3, 3)) * 10.0
         error = np.ones((3, 3))
         threshold = detect_threshold(DATA, nsigma=2.0, background=background,
                                      error=error)
-        ref = 12. * np.ones((3, 3))
+        ref = 12.0 * np.ones((3, 3))
         assert_allclose(threshold, ref)
 
-    def test_mask_value(self):
-        """Test detection with mask_value."""
-        with pytest.warns(AstropyDeprecationWarning):
-            threshold = detect_threshold(DATA, nsigma=1.0, mask_value=0.0)
-        ref = 2. * np.ones((3, 3))
-        assert_array_equal(threshold, ref)
-
     def test_image_mask(self):
         """
         Test detection with image_mask.
@@ -96,28 +116,17 @@ class TestDetectThreshold:
         """
         mask = REF1.astype(bool)
         sigma_clip = SigmaClip(sigma=10, maxiters=1)
-        threshold = detect_threshold(DATA, nsigma=1., error=0, mask=mask,
+        threshold = detect_threshold(DATA, nsigma=1.0, error=0, mask=mask,
                                      sigma_clip=sigma_clip)
-        ref = (1. / 8.) * np.ones((3, 3))
+        ref = (1.0 / 8.0) * np.ones((3, 3))
         assert_array_equal(threshold, ref)
 
-    def test_image_mask_override(self):
-        """Test that image_mask overrides mask_value."""
-        mask = REF1.astype(bool)
-        sigma_clip = SigmaClip(sigma=10, maxiters=1)
-        with pytest.warns(AstropyDeprecationWarning):
-            threshold = detect_threshold(DATA, nsigma=0.1, error=0,
-                                         mask_value=0.0,
-                                         mask=mask, sigma_clip=sigma_clip)
-            ref = np.ones((3, 3))
-            assert_array_equal(threshold, ref)
-
     def test_invalid_sigma_clip(self):
         with pytest.raises(TypeError):
             detect_threshold(DATA, 1.0, sigma_clip=10)
 
 
-@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 class TestDetectSources:
     def setup_class(self):
         self.data = np.array([[0, 1, 0], [0, 2, 0],
@@ -132,6 +141,17 @@ class TestDetectSources:
         segm = detect_sources(self.data, threshold=0.9, npixels=2)
         assert_array_equal(segm.data, self.refdata)
 
+        segm = detect_sources(self.data << u.uJy, threshold=0.9 * u.uJy,
+                              npixels=2)
+        assert_array_equal(segm.data, self.refdata)
+
+        with pytest.raises(ValueError):
+            detect_sources(self.data << u.uJy, threshold=0.9, npixels=2)
+        with pytest.raises(ValueError):
+            detect_sources(self.data, threshold=0.9 * u.Jy, npixels=2)
+        with pytest.raises(ValueError):
+            detect_sources(self.data << u.uJy, threshold=0.9 * u.m, npixels=2)
+
     def test_small_sources(self):
         """Test detection where sources are smaller than npixels size."""
         with pytest.warns(NoDetectionsWarning, match='No sources were found'):
@@ -171,7 +191,7 @@ class TestDetectSources:
 
     def test_zerothresh(self):
         """Test detection with zero threshold."""
-        segm = detect_sources(self.data, threshold=0., npixels=2)
+        segm = detect_sources(self.data, threshold=0.0, npixels=2)
         assert_array_equal(segm.data, self.refdata)
 
     def test_zerodet(self):
@@ -194,7 +214,7 @@ class TestDetectSources:
 
     def test_basic_kernel(self):
         """Test detection with kernel."""
-        kernel = np.ones((3, 3)) / 9.
+        kernel = np.ones((3, 3)) / 9.0
         threshold = 0.3
         expected = np.ones((3, 3))
         expected[2] = 0
@@ -232,24 +252,24 @@ class TestDetectSources:
 
     def test_mask(self):
         data = np.zeros((11, 11))
-        data[3:8, 3:8] = 5.
+        data[3:8, 3:8] = 5.0
         mask = np.zeros(data.shape, dtype=bool)
         mask[4:6, 4:6] = True
-        segm1 = detect_sources(data, 1., 1.)
-        segm2 = detect_sources(data, 1., 1., mask=mask)
+        segm1 = detect_sources(data, 1.0, 1.0)
+        segm2 = detect_sources(data, 1.0, 1.0, mask=mask)
         assert segm2.areas[0] == segm1.areas[0] - mask.sum()
 
         # mask with all True
         with pytest.raises(ValueError):
             mask = np.ones(data.shape, dtype=bool)
-            detect_sources(data, 1., 1., mask=mask)
+            detect_sources(data, 1.0, 1.0, mask=mask)
 
     def test_mask_shape(self):
         with pytest.raises(ValueError):
-            detect_sources(self.data, 1., 1., mask=np.ones((5, 5)))
+            detect_sources(self.data, 1.0, 1.0, mask=np.ones((5, 5)))
 
 
-@pytest.mark.skipif('not HAS_SCIPY')
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 class TestMakeSourceMask:
     def setup_class(self):
         self.data = make_4gaussians_image()
@@ -261,16 +281,6 @@ class TestMakeSourceMask:
             mask2 = make_source_mask(self.data, 5, 10, dilate_size=20)
         assert np.count_nonzero(mask2) > np.count_nonzero(mask1)
 
-    def test_kernel(self):
-        with pytest.warns(AstropyDeprecationWarning):
-            mask1 = make_source_mask(self.data, 5, 10, filter_fwhm=2,
-                                     filter_size=3)
-        sigma = 2 * gaussian_fwhm_to_sigma
-        kernel = Gaussian2DKernel(sigma, x_size=3, y_size=3)
-        with pytest.warns(AstropyDeprecationWarning):
-            mask2 = make_source_mask(self.data, 5, 10, kernel=kernel)
-        assert_allclose(mask1, mask2)
-
     def test_no_detections(self):
         with pytest.warns(AstropyDeprecationWarning):
             mask = make_source_mask(self.data, 100, 100)
