@@ -3,13 +3,11 @@
 This module provides tools for generating matplotlib colormaps.
 """
 
-from astropy.utils.decorators import deprecated_renamed_argument
 import numpy as np
 
 __all__ = ['make_random_cmap']
 
 
-@deprecated_renamed_argument('random_state', 'seed', '1.0')
 def make_random_cmap(ncolors=256, seed=None):
     """
     Make a matplotlib colormap consisting of (random) muted colors.
@@ -30,9 +28,8 @@ def make_random_cmap(ncolors=256, seed=None):
     Returns
     -------
     cmap : `matplotlib.colors.ListedColormap`
-        The matplotlib colormap with random colors.
+        The matplotlib colormap with random colors in RGBA format.
     """
-
     from matplotlib import colors
 
     rng = np.random.default_rng(seed)
@@ -42,4 +39,4 @@ def make_random_cmap(ncolors=256, seed=None):
     hsv = np.dstack((hue, sat, val))
     rgb = np.squeeze(colors.hsv_to_rgb(hsv))
 
-    return colors.ListedColormap(rgb)
+    return colors.ListedColormap(colors.to_rgba_array(rgb))
