@@ -4,10 +4,10 @@ Tests for the footprints module.
 """
 
 import numpy as np
-from numpy.testing import assert_equal
 import pytest
+from numpy.testing import assert_equal
 
-from ..footprints import circular_footprint
+from photutils.utils.footprints import circular_footprint
 
 
 def test_footprints():
